import * as i0 from '@angular/core';
import { Directive, Input, HostBinding, Component, ChangeDetectionStrategy } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from '@ironsource/fusion-ui/components/icon/v1';
import { IconModule } from '@ironsource/fusion-ui/components/icon/v1';
import { LoaderComponent } from '@ironsource/fusion-ui/components/loader/v4';
import { ButtonTestIdModifiers } from '@ironsource/fusion-ui/entities';
import { TestIdsService } from '@ironsource/fusion-ui/services/test-ids';
import { GenericPipe } from '@ironsource/fusion-ui/pipes/generic';

class ButtonBaseComponent {
    /**
     * Set button color type
     * @param value
     */
    set color(value) {
        this._color = value || 'default';
    }
    /**
     * Set button variant type
     * @param value
     */
    set variant(value) {
        this._variant = value || 'contained';
    }
    /**
     * Set button size
     * @param value
     */
    set size(value) {
        this._size = value || 'medium';
    }
    /**
     * Set button disabled state
     * @param value
     */
    set disabled(value) {
        this._disabled = value ?? false;
    }
    /**
     * Set button loading state
     * @param value
     */
    set loading(value) {
        this._loading = value ?? false;
    }
    get testAttribute() {
        return this.testIdsService.getTestAttribute(this.testId, this.testIdButtonModifiers.BUTTON);
    }
    get buttonClass() {
        return `${this.colorClass} ${this.variantClass} ${this.sizeClass}`;
    }
    get colorClass() {
        return 'fu-' + this._color;
    }
    get variantClass() {
        return 'fu-' + this._variant;
    }
    get sizeClass() {
        return 'fu-' + this._size;
    }
    get disabled() {
        return this._disabled;
    }
    get loading() {
        return this._loading;
    }
    constructor(injector) {
        this.injector = injector;
        /** @internal */
        this.testIdButtonModifiers = ButtonTestIdModifiers;
        /** @internal */
        this.testIdsService = this.injector.get(TestIdsService);
        this._color = 'default';
        this._variant = 'contained';
        this._size = 'medium';
        this._disabled = false;
        this._loading = false;
    }
    static { this.ɵfac = function ButtonBaseComponent_Factory(t) { return new (t || ButtonBaseComponent)(i0.ɵɵdirectiveInject(i0.Injector)); }; }
    static { this.ɵdir = /*@__PURE__*/ i0.ɵɵdefineDirective({ type: ButtonBaseComponent, hostVars: 1, hostBindings: function ButtonBaseComponent_HostBindings(rf, ctx) { if (rf & 2) {
            i0.ɵɵattribute("data-testid", ctx.testAttribute);
        } }, inputs: { testId: "testId", color: "color", variant: "variant", size: "size", disabled: "disabled", loading: "loading" } }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(ButtonBaseComponent, [{
        type: Directive
    }], () => [{ type: i0.Injector }], { testId: [{
            type: Input
        }], color: [{
            type: Input
        }], variant: [{
            type: Input
        }], size: [{
            type: Input
        }], disabled: [{
            type: Input
        }], loading: [{
            type: Input
        }], testAttribute: [{
            type: HostBinding,
            args: ['attr.data-testid']
        }] }); })();

function ButtonComponent_fusion_icon_1_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelement(0, "fusion-icon", 7);
    i0.ɵɵpipe(1, "generic");
} if (rf & 2) {
    const ctx_r0 = i0.ɵɵnextContext();
    i0.ɵɵstyleProp("color", ctx_r0.startIconColor);
    i0.ɵɵproperty("name", ctx_r0.startIconName);
    i0.ɵɵattribute("data-testid", i0.ɵɵpipeBind3(1, 4, ctx_r0.testIdsService.getTestAttribute.bind(ctx_r0), ctx_r0.testId, ctx_r0.testIdButtonModifiers.ICON));
} }
function ButtonComponent_fusion_icon_2_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelement(0, "fusion-icon", 8);
    i0.ɵɵpipe(1, "generic");
} if (rf & 2) {
    const ctx_r1 = i0.ɵɵnextContext();
    i0.ɵɵproperty("name", ctx_r1.iconName);
    i0.ɵɵattribute("data-testid", i0.ɵɵpipeBind3(1, 2, ctx_r1.testIdsService.getTestAttribute.bind(ctx_r1), ctx_r1.testId, ctx_r1.testIdButtonModifiers.ICON));
} }
function ButtonComponent_div_3_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelementStart(0, "div", 9);
    i0.ɵɵpipe(1, "generic");
    i0.ɵɵprojection(2);
    i0.ɵɵelementEnd();
} if (rf & 2) {
    const ctx_r2 = i0.ɵɵnextContext();
    i0.ɵɵattribute("data-testid", i0.ɵɵpipeBind3(1, 1, ctx_r2.testIdsService.getTestAttribute.bind(ctx_r2), ctx_r2.testId, ctx_r2.testIdButtonModifiers.CONTENT));
} }
function ButtonComponent_fusion_icon_4_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelement(0, "fusion-icon", 10);
    i0.ɵɵpipe(1, "generic");
} if (rf & 2) {
    const ctx_r3 = i0.ɵɵnextContext();
    i0.ɵɵstyleProp("color", ctx_r3.endIconColor);
    i0.ɵɵproperty("name", ctx_r3.endIconName);
    i0.ɵɵattribute("data-testid", i0.ɵɵpipeBind3(1, 4, ctx_r3.testIdsService.getTestAttribute.bind(ctx_r3), ctx_r3.testId, ctx_r3.testIdButtonModifiers.ICON));
} }
const _c0$1 = ["*"];
class ButtonComponent extends ButtonBaseComponent {
    set startIconName(value) {
        this._startIconName = value?.trim();
    }
    set startIconColor(value) {
        this._startIconColor = value;
    }
    set endIconName(value) {
        this._endIconName = value?.trim();
    }
    set endIconColor(value) {
        this._endIconColor = value;
    }
    set selected(value) {
        this._selected = value ?? false;
    }
    get selected() {
        return this._selected;
    }
    get startIconName() {
        return this._startIconName;
    }
    get startIconColor() {
        return this._startIconColor;
    }
    get endIconName() {
        return this._endIconName;
    }
    get endIconColor() {
        return this._endIconColor;
    }
    static { this.ɵfac = /*@__PURE__*/ (() => { let ɵButtonComponent_BaseFactory; return function ButtonComponent_Factory(t) { return (ɵButtonComponent_BaseFactory || (ɵButtonComponent_BaseFactory = i0.ɵɵgetInheritedFactory(ButtonComponent)))(t || ButtonComponent); }; })(); }
    static { this.ɵcmp = /*@__PURE__*/ i0.ɵɵdefineComponent({ type: ButtonComponent, selectors: [["fusion-button"]], hostAttrs: [1, "fusion-v4"], inputs: { startIconName: "startIconName", startIconColor: "startIconColor", endIconName: "endIconName", endIconColor: "endIconColor", selected: "selected" }, standalone: true, features: [i0.ɵɵInheritDefinitionFeature, i0.ɵɵStandaloneFeature], ngContentSelectors: _c0$1, decls: 8, vars: 17, consts: [[3, "disabled"], ["class", "fu-button-start-icon", 3, "color", "name", 4, "ngIf"], ["class", "fu-button-icon", 3, "name", 4, "ngIf"], ["class", "fu-button-content", 4, "ngIf"], ["class", "fu-button-end-icon", 3, "color", "name", 4, "ngIf"], [1, "fu-button-loading"], [2, "width", "16px", "height", "16px"], [1, "fu-button-start-icon", 3, "name"], [1, "fu-button-icon", 3, "name"], [1, "fu-button-content"], [1, "fu-button-end-icon", 3, "name"]], template: function ButtonComponent_Template(rf, ctx) { if (rf & 1) {
            i0.ɵɵprojectionDef();
            i0.ɵɵelementStart(0, "button", 0);
            i0.ɵɵtemplate(1, ButtonComponent_fusion_icon_1_Template, 2, 8, "fusion-icon", 1)(2, ButtonComponent_fusion_icon_2_Template, 2, 6, "fusion-icon", 2)(3, ButtonComponent_div_3_Template, 3, 5, "div", 3)(4, ButtonComponent_fusion_icon_4_Template, 2, 8, "fusion-icon", 4);
            i0.ɵɵelementStart(5, "div", 5);
            i0.ɵɵelement(6, "fusion-loader", 6);
            i0.ɵɵpipe(7, "generic");
            i0.ɵɵelementEnd()();
        } if (rf & 2) {
            i0.ɵɵclassMap(ctx.buttonClass);
            i0.ɵɵclassProp("fu-selected", ctx.selected)("fu-loading", ctx.loading);
            i0.ɵɵproperty("disabled", ctx.disabled || ctx.loading);
            i0.ɵɵattribute("data-testid", ctx.testId);
            i0.ɵɵadvance();
            i0.ɵɵproperty("ngIf", ctx.startIconName);
            i0.ɵɵadvance();
            i0.ɵɵproperty("ngIf", ctx.iconName);
            i0.ɵɵadvance();
            i0.ɵɵproperty("ngIf", !ctx.iconName);
            i0.ɵɵadvance();
            i0.ɵɵproperty("ngIf", ctx.endIconName);
            i0.ɵɵadvance(2);
            i0.ɵɵattribute("data-testid", i0.ɵɵpipeBind3(7, 13, ctx.testIdsService.getTestAttribute.bind(ctx), ctx.testId, ctx.testIdButtonModifiers.LOADER));
        } }, dependencies: [CommonModule, i1.NgIf, IconModule, i2.IconComponent, LoaderComponent, GenericPipe], styles: ["@import\"https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600;700&display=swap\";.fusion-v4[_ngcontent-%COMP%]{--background-default: #FFFFFF;--background-paper: hsl(0, 0%, 99%);--background-model-elevation: #FFFFFF;--background-backdrop: hsla(0, 0%, 0%, .11);--background-paper-elevation-0: hsl(0, 0%, 97.5%);--background-paper-elevation-1: hsl(0, 0%, 94.6%);--background-paper-elevation-2: hsl(0, 0%, 92%);--background-paper-elevation-3: hsl(0, 0%, 89.5%);--background-paper-elevation-4: hsl(0, 0%, 86.8%);--background-paper-elevation-5: hsl(0, 0%, 83%);--background-paper-elevation-6: hsl(0, 0%, 73.2%);--background-paper-elevation-7: hsl(0, 0%, 55.2%);--background-paper-elevation-8: hsl(0, 0%, 50.3%);--background-paper-elevation-9: hsl(0, 0%, 39.3%);--action-primary: hsl(0, 0%, 12.5%);--action-active: hsl(0, 0%, 50.3%);--action-hover: hsla(0, 0%, 0%, .05);--action-selected: hsl(0, 0%, 92%);--action-disabled: hsl(0, 0%, 87%);--action-disabled-background: hsl(0, 0%, 95%);--action-focus: hsl(0, 0%, 92%);--action-outlined-border: hsl(0, 0%, 73%);--default-light: hsl(0, 0%, 89.5%);--default-main: hsl(0, 0%, 94.51%);--default-dark: hsl(0, 0%, 92%);--default-outlined-border: hsl(0, 0%, 73.2%);--default-contrast-text: hsl(0, 0%, 12.5%);--default-button-contrast-text: hsl(0, 0%, 0%);--common-white: #FFFFFF;--common-black: #000000;--common-inverse-white: #FFFFFF;--common-inverse-black: #000000;--common-divider: hsl(0, 0%, 86.8%);--common-divider-elevation-0: hsl(0, 0%, 89%);--text-primary: hsl(0, 0%, 12.5%);--text-secondary: hsl(0, 0%, 39.3%);--text-disabled: hsl(0, 0%, 73.33%);--primary-lighter: hsl(209, 100%, 96.5%);--primary-light: hsl(209, 95%, 90.1%);--primary-main: hsl(206, 100%, 50%);--primary-main-8-p: hsla(206, 100%, 50%, .08);--primary-main-50-p: hsla(206, 100%, 50%, .5);--primary-dark: hsl(208, 93.5%, 47.4%);--primary-darker: hsl(211, 90%, 42%);--primary-outlined-border: hsl(206, 100%, 50%);--primary-contrast-text: hsl(216, 71%, 23%);--primary-button-contrast-text: hsl(0, 0%, 100%);--info-lighter: hsl(223, 98.4%, 97.1%);--info-light: hsl(224, 87.1%, 92%);--info-main: hsl(226, 70%, 55.5%);--info-main-8-p: hsla(226, 70%, 55.5%, .08);--info-main-50-p: hsla(226, 70%, 55.5%, .5);--info-dark: hsl(226, 58.6%, 51.3%);--info-darker: hsl(226, 55%, 45%);--info-outlined-border: hsl(226, 70%, 55.5%);--info-contrast-text: hsl(226, 50%, 24%);--info-button-contrast-text: hsl(0, 0%, 100%);--success-lighter: hsl(139, 55.2%, 94.5%);--success-light: hsl(141, 43.7%, 86%);--success-main: hsl(151, 55%, 41.5%);--success-main-8-p: hsla(151, 55%, 41.5%, .08);--success-main-50-p: hsla(151, 55%, 41.5%, .5);--success-dark: hsl(152, 57.5%, 37.6%);--success-darker: hsl(153, 67%, 28.5%);--success-outlined-border: hsl(151, 55%, 41.5%);--success-contrast-text: hsl(155, 40%, 16.5%);--success-button-contrast-text: hsl(0, 0%, 100%);--warning-lighter: hsl(45, 100%, 90.8%);--warning-light: hsl(40, 100%, 81.5%);--warning-main: hsl(42, 100%, 62%);--warning-main-8-p: hsla(42, 100%, 62%, .08);--warning-main-50-p: hsla(42, 100%, 62%, .5);--warning-dark: hsl(42, 100%, 55%);--warning-darker: hsl(25, 50%, 38%);--warning-outlined-border: hsl(42, 100%, 62%);--warning-contrast-text: hsl(25, 40%, 22%);--warning-button-contrast-text: hsl(24, 40%, 22%);--error-lighter: hsl(0, 100%, 96.8%);--error-light: hsl(0, 90.2%, 91.9%);--error-main: hsl(358, 75%, 59%);--error-main-8-p: hsla(358, 75%, 59%, .08);--error-main-50-p: hsla(358, 75%, 59%, .5);--error-dark: hsl(358, 67.4%, 54.6%);--error-darker: hsl(358, 65%, 47%);--error-outlined-border: hsl(358, 75%, 59%);--error-contrast-text: hsl(350, 63%, 24%);--error-button-contrast-text: hsl(0, 0%, 100%);--aba: #FFC134;--abb: #4F4FF5}.fusion-v4[_ngcontent-%COMP%]{--spacing-tockenset: 0px;--spacing-25: 2px;--spacing-50: 4px;--spacing-75: 6px;--spacing-100: 8px;--spacing-125: 10px;--spacing-150: 12px;--spacing-200: 16px;--spacing-250: 20px;--spacing-300: 24px;--spacing-400: 32px;--spacing-500: 40px;--spacing-600: 48px;--spacing-700: 56px;--spacing-800: 64px;--spacing-900: 72px;--spacing-1000: 80px}.fusion-v4[_ngcontent-%COMP%]{--border-radius-xs: 2px;--border-radius-sm: 4px;--border-radius-md: 6px;--border-radius-lg: 8px;--border-radius-xl: 16px;--border-radius-full: 100px}.font-v4-bold[_ngcontent-%COMP%], .font-v4-tab-label-2[_ngcontent-%COMP%], .font-v4-chart-2[_ngcontent-%COMP%], .font-v4-chart-1[_ngcontent-%COMP%]{font-family:Inter,sans-serif;font-weight:700;-webkit-font-smoothing:antialiased}.font-v4-semibold[_ngcontent-%COMP%], .font-v4-chip-label[_ngcontent-%COMP%], .font-v4-table-label[_ngcontent-%COMP%], [_nghost-%COMP%]   button[_ngcontent-%COMP%], .font-v4-button[_ngcontent-%COMP%], .font-v4-heading-6[_ngcontent-%COMP%], .font-v4-heading-5[_ngcontent-%COMP%], .font-v4-heading-4[_ngcontent-%COMP%], .font-v4-heading-3[_ngcontent-%COMP%], .font-v4-heading-2[_ngcontent-%COMP%], .font-v4-heading-1[_ngcontent-%COMP%], .font-v4-title[_ngcontent-%COMP%]{font-family:Inter,sans-serif;font-weight:600;-webkit-font-smoothing:antialiased}.font-v4-medium[_ngcontent-%COMP%], .font-v4-tab-label-1[_ngcontent-%COMP%], .font-v4-input-label[_ngcontent-%COMP%], .font-v4-overline[_ngcontent-%COMP%], .font-v4-subtitle-2[_ngcontent-%COMP%], .font-v4-subtitle-1[_ngcontent-%COMP%]{font-family:Inter,sans-serif;font-weight:500;-webkit-font-smoothing:antialiased}.font-v4-regular[_ngcontent-%COMP%], .font-v4-caption[_ngcontent-%COMP%], .font-v4-body-2[_ngcontent-%COMP%], .font-v4-body-1[_ngcontent-%COMP%]{font-family:Inter,sans-serif;font-weight:400;-webkit-font-smoothing:antialiased}.font-v4-title[_ngcontent-%COMP%]{font-size:2.5rem;line-height:3rem;letter-spacing:-.055rem}.font-v4-heading-1[_ngcontent-%COMP%]{font-size:1.5rem;line-height:1.75rem;letter-spacing:-.0285rem}.font-v4-heading-2[_ngcontent-%COMP%]{font-size:1.125rem;line-height:1.75rem;letter-spacing:-.01575rem}.font-v4-heading-3[_ngcontent-%COMP%]{font-size:1rem;line-height:1.5rem;letter-spacing:-.011rem}.font-v4-heading-4[_ngcontent-%COMP%]{font-size:.875rem;line-height:1rem;letter-spacing:unset}.font-v4-heading-5[_ngcontent-%COMP%]{font-size:.8125rem;line-height:16px;letter-spacing:unset}.font-v4-heading-6[_ngcontent-%COMP%]{font-size:.75rem;line-height:.75rem;letter-spacing:0}.font-v4-body-1[_ngcontent-%COMP%]{font-size:.875rem;line-height:1.25rem;letter-spacing:-.00525rem}.font-v4-body-2[_ngcontent-%COMP%]{font-size:.8125rem;line-height:1.25rem;letter-spacing:-.00244rem}.font-v4-subtitle-1[_ngcontent-%COMP%]{font-size:.875rem;line-height:1.25rem;letter-spacing:-.00525rem}.font-v4-subtitle-2[_ngcontent-%COMP%]{font-size:.8125rem;line-height:1.25rem;letter-spacing:-.00244rem}.font-v4-chart-1[_ngcontent-%COMP%]{font-size:1.5rem;line-height:1.5rem;letter-spacing:-.015rem}.font-v4-chart-2[_ngcontent-%COMP%]{font-size:1.25rem;line-height:1.25rem;letter-spacing:-.0125rem}[_nghost-%COMP%]   button[_ngcontent-%COMP%], .font-v4-button[_ngcontent-%COMP%]{font-size:.875rem;line-height:1.25rem;letter-spacing:.00875rem}.font-v4-overline[_ngcontent-%COMP%]{font-size:.75rem;line-height:1rem;letter-spacing:.045rem;text-transform:uppercase}.font-v4-caption[_ngcontent-%COMP%]{font-size:.75rem;line-height:1rem}.font-v4-table-label[_ngcontent-%COMP%]{font-size:.8125rem;line-height:1.25rem;letter-spacing:.00813rem}.font-v4-input-label[_ngcontent-%COMP%]{font-size:.8125rem;line-height:1rem;letter-spacing:.00813rem}.font-v4-tab-label-1[_ngcontent-%COMP%], .font-v4-tab-label-2[_ngcontent-%COMP%]{font-size:.875rem;line-height:1rem}.font-v4-chip-label[_ngcontent-%COMP%]{font-size:.75rem;line-height:1rem;letter-spacing:normal}[_nghost-%COMP%]{margin:0;padding:0}[_nghost-%COMP%]   button[_ngcontent-%COMP%]{box-sizing:border-box;display:flex;padding:var(--spacing-50, 4px) var(--spacing-100, 8px);justify-content:center;align-items:center;gap:var(--spacing-100, 8px);color:var(--default-button-contrast-text, hsl(0, 0%, 0%));background-color:var(--default-main, hsl(0, 0%, 94.51%));border:none;border-radius:var(--border-radius-md, 6px);transition:background-color .2s ease;position:relative}[_nghost-%COMP%]   button[_ngcontent-%COMP%]   .fu-button-loading[_ngcontent-%COMP%]{display:none}[_nghost-%COMP%]   button[_ngcontent-%COMP%]:hover{cursor:pointer;background-color:var(--default-light, hsl(0, 0%, 89.5%));outline:none}[_nghost-%COMP%]   button.fu-outlined[_ngcontent-%COMP%]{color:var(--text-primary, hsl(0, 0%, 12.5%));border:1px solid var(--default-outlined-border, hsl(0, 0%, 73.2%));padding:calc(var(--spacing-50, 4px) - 1px) calc(var(--spacing-100, 8px) - 1px);background:none}[_nghost-%COMP%]   button.fu-outlined[_ngcontent-%COMP%]:hover{border-color:var(--action-active, hsl(0, 0%, 50.3%));background-color:var(--action-hover, hsla(0, 0%, 0%, .05))}[_nghost-%COMP%]   button.fu-text[_ngcontent-%COMP%]{color:var(--text-primary, hsl(0, 0%, 12.5%));background:none}[_nghost-%COMP%]   button.fu-text[_ngcontent-%COMP%]:hover{background-color:var(--action-hover, hsla(0, 0%, 0%, .05))}[_nghost-%COMP%]   button.fu-primary[_ngcontent-%COMP%]{color:var(--primary-button-contrast-text, hsl(0, 0%, 100%));background-color:var(--primary-main, hsl(206, 100%, 50%))}[_nghost-%COMP%]   button.fu-primary[_ngcontent-%COMP%]:hover{background-color:var(--primary-dark, hsl(208, 93.5%, 47.4%))}[_nghost-%COMP%]   button.fu-primary.fu-outlined[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-primary.fu-text[_ngcontent-%COMP%]{color:var(--primary-main, hsl(206, 100%, 50%));background:none}[_nghost-%COMP%]   button.fu-primary.fu-outlined[_ngcontent-%COMP%]:hover, [_nghost-%COMP%]   button.fu-primary.fu-text[_ngcontent-%COMP%]:hover{background-color:var(--primary-lighter, hsl(209, 100%, 96.5%))}[_nghost-%COMP%]   button.fu-primary.fu-outlined[_ngcontent-%COMP%]{border-color:var(--primary-main, hsl(206, 100%, 50%))}[_nghost-%COMP%]   button.fu-danger[_ngcontent-%COMP%]{color:var(--error-button-contrast-text, hsl(0, 0%, 100%));background-color:var(--error-main, hsl(358, 75%, 59%))}[_nghost-%COMP%]   button.fu-danger[_ngcontent-%COMP%]:hover{background-color:var(--error-dark, hsl(358, 67.4%, 54.6%))}[_nghost-%COMP%]   button.fu-danger.fu-outlined[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-danger.fu-text[_ngcontent-%COMP%]{color:var(--error-main, hsl(358, 75%, 59%));background:none}[_nghost-%COMP%]   button.fu-danger.fu-outlined[_ngcontent-%COMP%]:hover, [_nghost-%COMP%]   button.fu-danger.fu-text[_ngcontent-%COMP%]:hover{background-color:var(--error-lighter, hsl(0, 100%, 96.8%))}[_nghost-%COMP%]   button.fu-danger.fu-outlined[_ngcontent-%COMP%]{border-color:var(--error-main, hsl(358, 75%, 59%))}[_nghost-%COMP%]   button.fu-info[_ngcontent-%COMP%]{color:var(--info-button-contrast-text, hsl(0, 0%, 100%));background-color:var(--info-main, hsl(226, 70%, 55.5%))}[_nghost-%COMP%]   button.fu-info[_ngcontent-%COMP%]:hover{background-color:var(--info-dark, hsl(226, 58.6%, 51.3%))}[_nghost-%COMP%]   button.fu-info.fu-outlined[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-info.fu-text[_ngcontent-%COMP%]{color:var(--info-main, hsl(226, 70%, 55.5%));background:none}[_nghost-%COMP%]   button.fu-info.fu-outlined[_ngcontent-%COMP%]:hover, [_nghost-%COMP%]   button.fu-info.fu-text[_ngcontent-%COMP%]:hover{background-color:var(--info-lighter, hsl(223, 98.4%, 97.1%))}[_nghost-%COMP%]   button.fu-info.fu-outlined[_ngcontent-%COMP%]{border-color:var(--info-main, hsl(226, 70%, 55.5%))}[_nghost-%COMP%]   button.fu-success[_ngcontent-%COMP%]{color:var(--success-button-contrast-text, hsl(0, 0%, 100%));background-color:var(--success-main, hsl(151, 55%, 41.5%))}[_nghost-%COMP%]   button.fu-success[_ngcontent-%COMP%]:hover{background-color:var(--success-dark, hsl(152, 57.5%, 37.6%))}[_nghost-%COMP%]   button.fu-success.fu-outlined[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-success.fu-text[_ngcontent-%COMP%]{color:var(--success-main, hsl(151, 55%, 41.5%));background:none}[_nghost-%COMP%]   button.fu-success.fu-outlined[_ngcontent-%COMP%]:hover, [_nghost-%COMP%]   button.fu-success.fu-text[_ngcontent-%COMP%]:hover{background-color:var(--success-lighter, hsl(139, 55.2%, 94.5%))}[_nghost-%COMP%]   button.fu-success.fu-outlined[_ngcontent-%COMP%]{border-color:var(--success-main, hsl(151, 55%, 41.5%))}[_nghost-%COMP%]   button.fu-warning[_ngcontent-%COMP%]{color:var(--warning-button-contrast-text, hsl(24, 40%, 22%));background-color:var(--warning-main, hsl(42, 100%, 62%))}[_nghost-%COMP%]   button.fu-warning[_ngcontent-%COMP%]:hover{background-color:var(--warning-dark, hsl(42, 100%, 55%))}[_nghost-%COMP%]   button.fu-warning.fu-outlined[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-warning.fu-text[_ngcontent-%COMP%]{color:var(--warning-darker, hsl(25, 50%, 38%));background:none}[_nghost-%COMP%]   button.fu-warning.fu-outlined[_ngcontent-%COMP%]:hover, [_nghost-%COMP%]   button.fu-warning.fu-text[_ngcontent-%COMP%]:hover{background-color:var(--warning-lighter, hsl(45, 100%, 90.8%))}[_nghost-%COMP%]   button.fu-warning.fu-outlined[_ngcontent-%COMP%]{border-color:var(--warning-darker, hsl(25, 50%, 38%))}[_nghost-%COMP%]   button.fu-small[_ngcontent-%COMP%]{padding:var(--spacing-25, 2px) var(--spacing-75, 6px)}[_nghost-%COMP%]   button.fu-large[_ngcontent-%COMP%]{padding:var(--spacing-75, 6px) var(--spacing-100, 8px)}[_nghost-%COMP%]   button.fu-extraLarge[_ngcontent-%COMP%]{padding:var(--spacing-125, 10px) var(--spacing-150, 12px)}[_nghost-%COMP%]   button.fu-outlined.fu-small[_ngcontent-%COMP%]{padding:calc(var(--spacing-25, 2px) - 1px) calc(var(--spacing-75, 6px) - 1px)}[_nghost-%COMP%]   button.fu-outlined.fu-large[_ngcontent-%COMP%]{padding:calc(var(--spacing-75, 6px) - 1px) calc(var(--spacing-100, 8px) - 1px)}[_nghost-%COMP%]   button.fu-outlined.fu-extraLarge[_ngcontent-%COMP%]{padding:calc(var(--spacing-125, 10px) - 1px) calc(var(--spacing-150, 12px) - 1px)}[_nghost-%COMP%]   button[_ngcontent-%COMP%]:disabled{cursor:default;color:var(--text-disabled, hsl(0, 0%, 73.33%));background-color:var(--action-disabled-background, hsl(0, 0%, 95%))}[_nghost-%COMP%]   button[_ngcontent-%COMP%]:disabled:hover{background-color:var(--action-disabled-background, hsl(0, 0%, 95%))}[_nghost-%COMP%]   button.fu-outlined[_ngcontent-%COMP%]:disabled{color:var(--text-disabled, hsl(0, 0%, 73.33%));border-color:var(--default-outlined-border, hsl(0, 0%, 73.2%));background:none!important}[_nghost-%COMP%]   button.fu-outlined[_ngcontent-%COMP%]:disabled:hover{background-color:var(--action-disabled-background, hsl(0, 0%, 95%))}[_nghost-%COMP%]   button.fu-text[_ngcontent-%COMP%]:disabled{background:none;color:var(--text-disabled, hsl(0, 0%, 73.33%))}[_nghost-%COMP%]   button.fu-text[_ngcontent-%COMP%]:disabled:hover{background:none}[_nghost-%COMP%]   button.fu-loading[_ngcontent-%COMP%]   .fu-button-content[_ngcontent-%COMP%]{visibility:hidden}[_nghost-%COMP%]   button.fu-loading[_ngcontent-%COMP%]   .fu-button-loading[_ngcontent-%COMP%]{display:block;position:absolute}[_nghost-%COMP%]   button.fu-loading[_ngcontent-%COMP%]   .fu-button-start-icon[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-loading[_ngcontent-%COMP%]   .fu-button-end-icon[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-loading[_ngcontent-%COMP%]   .fu-button-icon[_ngcontent-%COMP%]{visibility:hidden}[_nghost-%COMP%]   button.fu-outlined.fu-loading[_ngcontent-%COMP%]:disabled{background:var(--action-disabled-background, hsl(0, 0%, 95%))}[_nghost-%COMP%]   button[_ngcontent-%COMP%]   .fu-button-start-icon[_ngcontent-%COMP%], [_nghost-%COMP%]   button[_ngcontent-%COMP%]   .fu-button-end-icon[_ngcontent-%COMP%]{width:16px;height:16px}[_nghost-%COMP%]   button.fu-selected[_ngcontent-%COMP%]{border-width:2px;border-color:var(--action-active, hsl(0, 0%, 50.3%));background-color:var(--action-selected, hsl(0, 0%, 92%));padding:2px 6px}[_nghost-%COMP%]   button.fu-selected.fu-small[_ngcontent-%COMP%]{padding:0 4px}[_nghost-%COMP%]   button.fu-selected.fu-large[_ngcontent-%COMP%]{padding:4px 6px}[_nghost-%COMP%]   button.fu-selected.fu-extraLarge[_ngcontent-%COMP%]{padding:8px 10px}"], changeDetection: 0 }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(ButtonComponent, [{
        type: Component,
        args: [{ selector: 'fusion-button', standalone: true, imports: [CommonModule, IconModule, LoaderComponent, GenericPipe], host: { class: 'fusion-v4' }, changeDetection: ChangeDetectionStrategy.OnPush, template: "<button [class]=\"buttonClass\" [class.fu-selected]=\"selected\" [class.fu-loading]=\"loading\"\n        [disabled]=\"disabled || loading\" [attr.data-testid]=\"testId\">\n    <fusion-icon *ngIf=\"startIconName\" [style.color]=\"startIconColor\" class=\"fu-button-start-icon\"\n                 [name]=\"startIconName\"\n                 [attr.data-testid]=\"testIdsService.getTestAttribute.bind(this) | generic:testId:testIdButtonModifiers.ICON\"></fusion-icon>\n    <fusion-icon *ngIf=\"iconName\" class=\"fu-button-icon\" [name]=\"iconName\"\n                 [attr.data-testid]=\"testIdsService.getTestAttribute.bind(this) | generic:testId:testIdButtonModifiers.ICON\"></fusion-icon>\n    <div *ngIf=\"!iconName\" class=\"fu-button-content\"\n         [attr.data-testid]=\"testIdsService.getTestAttribute.bind(this) | generic:testId:testIdButtonModifiers.CONTENT\">\n        <ng-content></ng-content>\n    </div>\n    <fusion-icon *ngIf=\"endIconName\" [style.color]=\"endIconColor\" class=\"fu-button-end-icon\" [name]=\"endIconName\"\n                 [attr.data-testid]=\"testIdsService.getTestAttribute.bind(this) | generic:testId:testIdButtonModifiers.ICON\"></fusion-icon>\n    <div class=\"fu-button-loading\">\n        <fusion-loader\n            [attr.data-testid]=\"testIdsService.getTestAttribute.bind(this) | generic:testId:testIdButtonModifiers.LOADER\"\n            style=\"width: 16px; height: 16px\"></fusion-loader>\n    </div>\n</button>\n", styles: ["@import\"https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600;700&display=swap\";.fusion-v4{--background-default: #FFFFFF;--background-paper: hsl(0, 0%, 99%);--background-model-elevation: #FFFFFF;--background-backdrop: hsla(0, 0%, 0%, .11);--background-paper-elevation-0: hsl(0, 0%, 97.5%);--background-paper-elevation-1: hsl(0, 0%, 94.6%);--background-paper-elevation-2: hsl(0, 0%, 92%);--background-paper-elevation-3: hsl(0, 0%, 89.5%);--background-paper-elevation-4: hsl(0, 0%, 86.8%);--background-paper-elevation-5: hsl(0, 0%, 83%);--background-paper-elevation-6: hsl(0, 0%, 73.2%);--background-paper-elevation-7: hsl(0, 0%, 55.2%);--background-paper-elevation-8: hsl(0, 0%, 50.3%);--background-paper-elevation-9: hsl(0, 0%, 39.3%);--action-primary: hsl(0, 0%, 12.5%);--action-active: hsl(0, 0%, 50.3%);--action-hover: hsla(0, 0%, 0%, .05);--action-selected: hsl(0, 0%, 92%);--action-disabled: hsl(0, 0%, 87%);--action-disabled-background: hsl(0, 0%, 95%);--action-focus: hsl(0, 0%, 92%);--action-outlined-border: hsl(0, 0%, 73%);--default-light: hsl(0, 0%, 89.5%);--default-main: hsl(0, 0%, 94.51%);--default-dark: hsl(0, 0%, 92%);--default-outlined-border: hsl(0, 0%, 73.2%);--default-contrast-text: hsl(0, 0%, 12.5%);--default-button-contrast-text: hsl(0, 0%, 0%);--common-white: #FFFFFF;--common-black: #000000;--common-inverse-white: #FFFFFF;--common-inverse-black: #000000;--common-divider: hsl(0, 0%, 86.8%);--common-divider-elevation-0: hsl(0, 0%, 89%);--text-primary: hsl(0, 0%, 12.5%);--text-secondary: hsl(0, 0%, 39.3%);--text-disabled: hsl(0, 0%, 73.33%);--primary-lighter: hsl(209, 100%, 96.5%);--primary-light: hsl(209, 95%, 90.1%);--primary-main: hsl(206, 100%, 50%);--primary-main-8-p: hsla(206, 100%, 50%, .08);--primary-main-50-p: hsla(206, 100%, 50%, .5);--primary-dark: hsl(208, 93.5%, 47.4%);--primary-darker: hsl(211, 90%, 42%);--primary-outlined-border: hsl(206, 100%, 50%);--primary-contrast-text: hsl(216, 71%, 23%);--primary-button-contrast-text: hsl(0, 0%, 100%);--info-lighter: hsl(223, 98.4%, 97.1%);--info-light: hsl(224, 87.1%, 92%);--info-main: hsl(226, 70%, 55.5%);--info-main-8-p: hsla(226, 70%, 55.5%, .08);--info-main-50-p: hsla(226, 70%, 55.5%, .5);--info-dark: hsl(226, 58.6%, 51.3%);--info-darker: hsl(226, 55%, 45%);--info-outlined-border: hsl(226, 70%, 55.5%);--info-contrast-text: hsl(226, 50%, 24%);--info-button-contrast-text: hsl(0, 0%, 100%);--success-lighter: hsl(139, 55.2%, 94.5%);--success-light: hsl(141, 43.7%, 86%);--success-main: hsl(151, 55%, 41.5%);--success-main-8-p: hsla(151, 55%, 41.5%, .08);--success-main-50-p: hsla(151, 55%, 41.5%, .5);--success-dark: hsl(152, 57.5%, 37.6%);--success-darker: hsl(153, 67%, 28.5%);--success-outlined-border: hsl(151, 55%, 41.5%);--success-contrast-text: hsl(155, 40%, 16.5%);--success-button-contrast-text: hsl(0, 0%, 100%);--warning-lighter: hsl(45, 100%, 90.8%);--warning-light: hsl(40, 100%, 81.5%);--warning-main: hsl(42, 100%, 62%);--warning-main-8-p: hsla(42, 100%, 62%, .08);--warning-main-50-p: hsla(42, 100%, 62%, .5);--warning-dark: hsl(42, 100%, 55%);--warning-darker: hsl(25, 50%, 38%);--warning-outlined-border: hsl(42, 100%, 62%);--warning-contrast-text: hsl(25, 40%, 22%);--warning-button-contrast-text: hsl(24, 40%, 22%);--error-lighter: hsl(0, 100%, 96.8%);--error-light: hsl(0, 90.2%, 91.9%);--error-main: hsl(358, 75%, 59%);--error-main-8-p: hsla(358, 75%, 59%, .08);--error-main-50-p: hsla(358, 75%, 59%, .5);--error-dark: hsl(358, 67.4%, 54.6%);--error-darker: hsl(358, 65%, 47%);--error-outlined-border: hsl(358, 75%, 59%);--error-contrast-text: hsl(350, 63%, 24%);--error-button-contrast-text: hsl(0, 0%, 100%);--aba: #FFC134;--abb: #4F4FF5}.fusion-v4{--spacing-tockenset: 0px;--spacing-25: 2px;--spacing-50: 4px;--spacing-75: 6px;--spacing-100: 8px;--spacing-125: 10px;--spacing-150: 12px;--spacing-200: 16px;--spacing-250: 20px;--spacing-300: 24px;--spacing-400: 32px;--spacing-500: 40px;--spacing-600: 48px;--spacing-700: 56px;--spacing-800: 64px;--spacing-900: 72px;--spacing-1000: 80px}.fusion-v4{--border-radius-xs: 2px;--border-radius-sm: 4px;--border-radius-md: 6px;--border-radius-lg: 8px;--border-radius-xl: 16px;--border-radius-full: 100px}.font-v4-bold,.font-v4-tab-label-2,.font-v4-chart-2,.font-v4-chart-1{font-family:Inter,sans-serif;font-weight:700;-webkit-font-smoothing:antialiased}.font-v4-semibold,.font-v4-chip-label,.font-v4-table-label,:host button,.font-v4-button,.font-v4-heading-6,.font-v4-heading-5,.font-v4-heading-4,.font-v4-heading-3,.font-v4-heading-2,.font-v4-heading-1,.font-v4-title{font-family:Inter,sans-serif;font-weight:600;-webkit-font-smoothing:antialiased}.font-v4-medium,.font-v4-tab-label-1,.font-v4-input-label,.font-v4-overline,.font-v4-subtitle-2,.font-v4-subtitle-1{font-family:Inter,sans-serif;font-weight:500;-webkit-font-smoothing:antialiased}.font-v4-regular,.font-v4-caption,.font-v4-body-2,.font-v4-body-1{font-family:Inter,sans-serif;font-weight:400;-webkit-font-smoothing:antialiased}.font-v4-title{font-size:2.5rem;line-height:3rem;letter-spacing:-.055rem}.font-v4-heading-1{font-size:1.5rem;line-height:1.75rem;letter-spacing:-.0285rem}.font-v4-heading-2{font-size:1.125rem;line-height:1.75rem;letter-spacing:-.01575rem}.font-v4-heading-3{font-size:1rem;line-height:1.5rem;letter-spacing:-.011rem}.font-v4-heading-4{font-size:.875rem;line-height:1rem;letter-spacing:unset}.font-v4-heading-5{font-size:.8125rem;line-height:16px;letter-spacing:unset}.font-v4-heading-6{font-size:.75rem;line-height:.75rem;letter-spacing:0}.font-v4-body-1{font-size:.875rem;line-height:1.25rem;letter-spacing:-.00525rem}.font-v4-body-2{font-size:.8125rem;line-height:1.25rem;letter-spacing:-.00244rem}.font-v4-subtitle-1{font-size:.875rem;line-height:1.25rem;letter-spacing:-.00525rem}.font-v4-subtitle-2{font-size:.8125rem;line-height:1.25rem;letter-spacing:-.00244rem}.font-v4-chart-1{font-size:1.5rem;line-height:1.5rem;letter-spacing:-.015rem}.font-v4-chart-2{font-size:1.25rem;line-height:1.25rem;letter-spacing:-.0125rem}:host button,.font-v4-button{font-size:.875rem;line-height:1.25rem;letter-spacing:.00875rem}.font-v4-overline{font-size:.75rem;line-height:1rem;letter-spacing:.045rem;text-transform:uppercase}.font-v4-caption{font-size:.75rem;line-height:1rem}.font-v4-table-label{font-size:.8125rem;line-height:1.25rem;letter-spacing:.00813rem}.font-v4-input-label{font-size:.8125rem;line-height:1rem;letter-spacing:.00813rem}.font-v4-tab-label-1,.font-v4-tab-label-2{font-size:.875rem;line-height:1rem}.font-v4-chip-label{font-size:.75rem;line-height:1rem;letter-spacing:normal}:host{margin:0;padding:0}:host button{box-sizing:border-box;display:flex;padding:var(--spacing-50, 4px) var(--spacing-100, 8px);justify-content:center;align-items:center;gap:var(--spacing-100, 8px);color:var(--default-button-contrast-text, hsl(0, 0%, 0%));background-color:var(--default-main, hsl(0, 0%, 94.51%));border:none;border-radius:var(--border-radius-md, 6px);transition:background-color .2s ease;position:relative}:host button .fu-button-loading{display:none}:host button:hover{cursor:pointer;background-color:var(--default-light, hsl(0, 0%, 89.5%));outline:none}:host button.fu-outlined{color:var(--text-primary, hsl(0, 0%, 12.5%));border:1px solid var(--default-outlined-border, hsl(0, 0%, 73.2%));padding:calc(var(--spacing-50, 4px) - 1px) calc(var(--spacing-100, 8px) - 1px);background:none}:host button.fu-outlined:hover{border-color:var(--action-active, hsl(0, 0%, 50.3%));background-color:var(--action-hover, hsla(0, 0%, 0%, .05))}:host button.fu-text{color:var(--text-primary, hsl(0, 0%, 12.5%));background:none}:host button.fu-text:hover{background-color:var(--action-hover, hsla(0, 0%, 0%, .05))}:host button.fu-primary{color:var(--primary-button-contrast-text, hsl(0, 0%, 100%));background-color:var(--primary-main, hsl(206, 100%, 50%))}:host button.fu-primary:hover{background-color:var(--primary-dark, hsl(208, 93.5%, 47.4%))}:host button.fu-primary.fu-outlined,:host button.fu-primary.fu-text{color:var(--primary-main, hsl(206, 100%, 50%));background:none}:host button.fu-primary.fu-outlined:hover,:host button.fu-primary.fu-text:hover{background-color:var(--primary-lighter, hsl(209, 100%, 96.5%))}:host button.fu-primary.fu-outlined{border-color:var(--primary-main, hsl(206, 100%, 50%))}:host button.fu-danger{color:var(--error-button-contrast-text, hsl(0, 0%, 100%));background-color:var(--error-main, hsl(358, 75%, 59%))}:host button.fu-danger:hover{background-color:var(--error-dark, hsl(358, 67.4%, 54.6%))}:host button.fu-danger.fu-outlined,:host button.fu-danger.fu-text{color:var(--error-main, hsl(358, 75%, 59%));background:none}:host button.fu-danger.fu-outlined:hover,:host button.fu-danger.fu-text:hover{background-color:var(--error-lighter, hsl(0, 100%, 96.8%))}:host button.fu-danger.fu-outlined{border-color:var(--error-main, hsl(358, 75%, 59%))}:host button.fu-info{color:var(--info-button-contrast-text, hsl(0, 0%, 100%));background-color:var(--info-main, hsl(226, 70%, 55.5%))}:host button.fu-info:hover{background-color:var(--info-dark, hsl(226, 58.6%, 51.3%))}:host button.fu-info.fu-outlined,:host button.fu-info.fu-text{color:var(--info-main, hsl(226, 70%, 55.5%));background:none}:host button.fu-info.fu-outlined:hover,:host button.fu-info.fu-text:hover{background-color:var(--info-lighter, hsl(223, 98.4%, 97.1%))}:host button.fu-info.fu-outlined{border-color:var(--info-main, hsl(226, 70%, 55.5%))}:host button.fu-success{color:var(--success-button-contrast-text, hsl(0, 0%, 100%));background-color:var(--success-main, hsl(151, 55%, 41.5%))}:host button.fu-success:hover{background-color:var(--success-dark, hsl(152, 57.5%, 37.6%))}:host button.fu-success.fu-outlined,:host button.fu-success.fu-text{color:var(--success-main, hsl(151, 55%, 41.5%));background:none}:host button.fu-success.fu-outlined:hover,:host button.fu-success.fu-text:hover{background-color:var(--success-lighter, hsl(139, 55.2%, 94.5%))}:host button.fu-success.fu-outlined{border-color:var(--success-main, hsl(151, 55%, 41.5%))}:host button.fu-warning{color:var(--warning-button-contrast-text, hsl(24, 40%, 22%));background-color:var(--warning-main, hsl(42, 100%, 62%))}:host button.fu-warning:hover{background-color:var(--warning-dark, hsl(42, 100%, 55%))}:host button.fu-warning.fu-outlined,:host button.fu-warning.fu-text{color:var(--warning-darker, hsl(25, 50%, 38%));background:none}:host button.fu-warning.fu-outlined:hover,:host button.fu-warning.fu-text:hover{background-color:var(--warning-lighter, hsl(45, 100%, 90.8%))}:host button.fu-warning.fu-outlined{border-color:var(--warning-darker, hsl(25, 50%, 38%))}:host button.fu-small{padding:var(--spacing-25, 2px) var(--spacing-75, 6px)}:host button.fu-large{padding:var(--spacing-75, 6px) var(--spacing-100, 8px)}:host button.fu-extraLarge{padding:var(--spacing-125, 10px) var(--spacing-150, 12px)}:host button.fu-outlined.fu-small{padding:calc(var(--spacing-25, 2px) - 1px) calc(var(--spacing-75, 6px) - 1px)}:host button.fu-outlined.fu-large{padding:calc(var(--spacing-75, 6px) - 1px) calc(var(--spacing-100, 8px) - 1px)}:host button.fu-outlined.fu-extraLarge{padding:calc(var(--spacing-125, 10px) - 1px) calc(var(--spacing-150, 12px) - 1px)}:host button:disabled{cursor:default;color:var(--text-disabled, hsl(0, 0%, 73.33%));background-color:var(--action-disabled-background, hsl(0, 0%, 95%))}:host button:disabled:hover{background-color:var(--action-disabled-background, hsl(0, 0%, 95%))}:host button.fu-outlined:disabled{color:var(--text-disabled, hsl(0, 0%, 73.33%));border-color:var(--default-outlined-border, hsl(0, 0%, 73.2%));background:none!important}:host button.fu-outlined:disabled:hover{background-color:var(--action-disabled-background, hsl(0, 0%, 95%))}:host button.fu-text:disabled{background:none;color:var(--text-disabled, hsl(0, 0%, 73.33%))}:host button.fu-text:disabled:hover{background:none}:host button.fu-loading .fu-button-content{visibility:hidden}:host button.fu-loading .fu-button-loading{display:block;position:absolute}:host button.fu-loading .fu-button-start-icon,:host button.fu-loading .fu-button-end-icon,:host button.fu-loading .fu-button-icon{visibility:hidden}:host button.fu-outlined.fu-loading:disabled{background:var(--action-disabled-background, hsl(0, 0%, 95%))}:host button .fu-button-start-icon,:host button .fu-button-end-icon{width:16px;height:16px}:host button.fu-selected{border-width:2px;border-color:var(--action-active, hsl(0, 0%, 50.3%));background-color:var(--action-selected, hsl(0, 0%, 92%));padding:2px 6px}:host button.fu-selected.fu-small{padding:0 4px}:host button.fu-selected.fu-large{padding:4px 6px}:host button.fu-selected.fu-extraLarge{padding:8px 10px}\n"] }]
    }], null, { startIconName: [{
            type: Input
        }], startIconColor: [{
            type: Input
        }], endIconName: [{
            type: Input
        }], endIconColor: [{
            type: Input
        }], selected: [{
            type: Input
        }] }); })();
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassDebugInfo(ButtonComponent, { className: "ButtonComponent", filePath: "button/button.component.ts", lineNumber: 17 }); })();

function IconButtonComponent_fusion_icon_1_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelement(0, "fusion-icon", 7);
    i0.ɵɵpipe(1, "generic");
} if (rf & 2) {
    const ctx_r0 = i0.ɵɵnextContext();
    i0.ɵɵstyleProp("color", ctx_r0.startIconColor);
    i0.ɵɵproperty("name", ctx_r0.startIconName);
    i0.ɵɵattribute("data-testid", i0.ɵɵpipeBind3(1, 4, ctx_r0.testIdsService.getTestAttribute.bind(ctx_r0), ctx_r0.testId, ctx_r0.testIdButtonModifiers.ICON));
} }
function IconButtonComponent_fusion_icon_2_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelement(0, "fusion-icon", 8);
    i0.ɵɵpipe(1, "generic");
} if (rf & 2) {
    const ctx_r1 = i0.ɵɵnextContext();
    i0.ɵɵproperty("name", ctx_r1.iconName);
    i0.ɵɵattribute("data-testid", i0.ɵɵpipeBind3(1, 2, ctx_r1.testIdsService.getTestAttribute.bind(ctx_r1), ctx_r1.testId, ctx_r1.testIdButtonModifiers.ICON));
} }
function IconButtonComponent_div_3_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelementStart(0, "div", 9);
    i0.ɵɵpipe(1, "generic");
    i0.ɵɵprojection(2);
    i0.ɵɵelementEnd();
} if (rf & 2) {
    const ctx_r2 = i0.ɵɵnextContext();
    i0.ɵɵattribute("data-testid", i0.ɵɵpipeBind3(1, 1, ctx_r2.testIdsService.getTestAttribute.bind(ctx_r2), ctx_r2.testId, ctx_r2.testIdButtonModifiers.CONTENT));
} }
function IconButtonComponent_fusion_icon_4_Template(rf, ctx) { if (rf & 1) {
    i0.ɵɵelement(0, "fusion-icon", 10);
    i0.ɵɵpipe(1, "generic");
} if (rf & 2) {
    const ctx_r3 = i0.ɵɵnextContext();
    i0.ɵɵstyleProp("color", ctx_r3.endIconColor);
    i0.ɵɵproperty("name", ctx_r3.endIconName);
    i0.ɵɵattribute("data-testid", i0.ɵɵpipeBind3(1, 4, ctx_r3.testIdsService.getTestAttribute.bind(ctx_r3), ctx_r3.testId, ctx_r3.testIdButtonModifiers.ICON));
} }
const _c0 = ["*"];
class IconButtonComponent extends ButtonBaseComponent {
    constructor() {
        super(...arguments);
        this._variantIcon = 'default';
        this._colorIcon = 'default';
    }
    set iconName(value) {
        this._iconName = value.trim();
    }
    /**
     * Set button variant type
     * @param value
     */
    set color(value) {
        this._colorIcon = value ?? 'default';
    }
    /**
     * Set button variant type
     * @param value
     */
    set variant(value) {
        this._variantIcon = value ?? 'default';
    }
    set size(value) {
        this._size = value ?? 'medium';
    }
    get variantClass() {
        return 'fu-' + this._variantIcon;
    }
    get colorClass() {
        return 'fu-' + this._colorIcon;
    }
    get iconName() {
        return this._iconName;
    }
    static { this.ɵfac = /*@__PURE__*/ (() => { let ɵIconButtonComponent_BaseFactory; return function IconButtonComponent_Factory(t) { return (ɵIconButtonComponent_BaseFactory || (ɵIconButtonComponent_BaseFactory = i0.ɵɵgetInheritedFactory(IconButtonComponent)))(t || IconButtonComponent); }; })(); }
    static { this.ɵcmp = /*@__PURE__*/ i0.ɵɵdefineComponent({ type: IconButtonComponent, selectors: [["fusion-icon-button"]], hostAttrs: [1, "fusion-v4"], inputs: { iconName: "iconName", color: "color", variant: "variant", size: "size" }, standalone: true, features: [i0.ɵɵInheritDefinitionFeature, i0.ɵɵStandaloneFeature], ngContentSelectors: _c0, decls: 8, vars: 17, consts: [[3, "disabled"], ["class", "fu-button-start-icon", 3, "color", "name", 4, "ngIf"], ["class", "fu-button-icon", 3, "name", 4, "ngIf"], ["class", "fu-button-content", 4, "ngIf"], ["class", "fu-button-end-icon", 3, "color", "name", 4, "ngIf"], [1, "fu-button-loading"], [2, "width", "16px", "height", "16px"], [1, "fu-button-start-icon", 3, "name"], [1, "fu-button-icon", 3, "name"], [1, "fu-button-content"], [1, "fu-button-end-icon", 3, "name"]], template: function IconButtonComponent_Template(rf, ctx) { if (rf & 1) {
            i0.ɵɵprojectionDef();
            i0.ɵɵelementStart(0, "button", 0);
            i0.ɵɵtemplate(1, IconButtonComponent_fusion_icon_1_Template, 2, 8, "fusion-icon", 1)(2, IconButtonComponent_fusion_icon_2_Template, 2, 6, "fusion-icon", 2)(3, IconButtonComponent_div_3_Template, 3, 5, "div", 3)(4, IconButtonComponent_fusion_icon_4_Template, 2, 8, "fusion-icon", 4);
            i0.ɵɵelementStart(5, "div", 5);
            i0.ɵɵelement(6, "fusion-loader", 6);
            i0.ɵɵpipe(7, "generic");
            i0.ɵɵelementEnd()();
        } if (rf & 2) {
            i0.ɵɵclassMap(ctx.buttonClass);
            i0.ɵɵclassProp("fu-selected", ctx.selected)("fu-loading", ctx.loading);
            i0.ɵɵproperty("disabled", ctx.disabled || ctx.loading);
            i0.ɵɵattribute("data-testid", ctx.testId);
            i0.ɵɵadvance();
            i0.ɵɵproperty("ngIf", ctx.startIconName);
            i0.ɵɵadvance();
            i0.ɵɵproperty("ngIf", ctx.iconName);
            i0.ɵɵadvance();
            i0.ɵɵproperty("ngIf", !ctx.iconName);
            i0.ɵɵadvance();
            i0.ɵɵproperty("ngIf", ctx.endIconName);
            i0.ɵɵadvance(2);
            i0.ɵɵattribute("data-testid", i0.ɵɵpipeBind3(7, 13, ctx.testIdsService.getTestAttribute.bind(ctx), ctx.testId, ctx.testIdButtonModifiers.LOADER));
        } }, dependencies: [CommonModule, i1.NgIf, IconModule, i2.IconComponent, LoaderComponent, GenericPipe], styles: ["@import\"https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600;700&display=swap\";.fusion-v4[_ngcontent-%COMP%]{--background-default: #FFFFFF;--background-paper: hsl(0, 0%, 99%);--background-model-elevation: #FFFFFF;--background-backdrop: hsla(0, 0%, 0%, .11);--background-paper-elevation-0: hsl(0, 0%, 97.5%);--background-paper-elevation-1: hsl(0, 0%, 94.6%);--background-paper-elevation-2: hsl(0, 0%, 92%);--background-paper-elevation-3: hsl(0, 0%, 89.5%);--background-paper-elevation-4: hsl(0, 0%, 86.8%);--background-paper-elevation-5: hsl(0, 0%, 83%);--background-paper-elevation-6: hsl(0, 0%, 73.2%);--background-paper-elevation-7: hsl(0, 0%, 55.2%);--background-paper-elevation-8: hsl(0, 0%, 50.3%);--background-paper-elevation-9: hsl(0, 0%, 39.3%);--action-primary: hsl(0, 0%, 12.5%);--action-active: hsl(0, 0%, 50.3%);--action-hover: hsla(0, 0%, 0%, .05);--action-selected: hsl(0, 0%, 92%);--action-disabled: hsl(0, 0%, 87%);--action-disabled-background: hsl(0, 0%, 95%);--action-focus: hsl(0, 0%, 92%);--action-outlined-border: hsl(0, 0%, 73%);--default-light: hsl(0, 0%, 89.5%);--default-main: hsl(0, 0%, 94.51%);--default-dark: hsl(0, 0%, 92%);--default-outlined-border: hsl(0, 0%, 73.2%);--default-contrast-text: hsl(0, 0%, 12.5%);--default-button-contrast-text: hsl(0, 0%, 0%);--common-white: #FFFFFF;--common-black: #000000;--common-inverse-white: #FFFFFF;--common-inverse-black: #000000;--common-divider: hsl(0, 0%, 86.8%);--common-divider-elevation-0: hsl(0, 0%, 89%);--text-primary: hsl(0, 0%, 12.5%);--text-secondary: hsl(0, 0%, 39.3%);--text-disabled: hsl(0, 0%, 73.33%);--primary-lighter: hsl(209, 100%, 96.5%);--primary-light: hsl(209, 95%, 90.1%);--primary-main: hsl(206, 100%, 50%);--primary-main-8-p: hsla(206, 100%, 50%, .08);--primary-main-50-p: hsla(206, 100%, 50%, .5);--primary-dark: hsl(208, 93.5%, 47.4%);--primary-darker: hsl(211, 90%, 42%);--primary-outlined-border: hsl(206, 100%, 50%);--primary-contrast-text: hsl(216, 71%, 23%);--primary-button-contrast-text: hsl(0, 0%, 100%);--info-lighter: hsl(223, 98.4%, 97.1%);--info-light: hsl(224, 87.1%, 92%);--info-main: hsl(226, 70%, 55.5%);--info-main-8-p: hsla(226, 70%, 55.5%, .08);--info-main-50-p: hsla(226, 70%, 55.5%, .5);--info-dark: hsl(226, 58.6%, 51.3%);--info-darker: hsl(226, 55%, 45%);--info-outlined-border: hsl(226, 70%, 55.5%);--info-contrast-text: hsl(226, 50%, 24%);--info-button-contrast-text: hsl(0, 0%, 100%);--success-lighter: hsl(139, 55.2%, 94.5%);--success-light: hsl(141, 43.7%, 86%);--success-main: hsl(151, 55%, 41.5%);--success-main-8-p: hsla(151, 55%, 41.5%, .08);--success-main-50-p: hsla(151, 55%, 41.5%, .5);--success-dark: hsl(152, 57.5%, 37.6%);--success-darker: hsl(153, 67%, 28.5%);--success-outlined-border: hsl(151, 55%, 41.5%);--success-contrast-text: hsl(155, 40%, 16.5%);--success-button-contrast-text: hsl(0, 0%, 100%);--warning-lighter: hsl(45, 100%, 90.8%);--warning-light: hsl(40, 100%, 81.5%);--warning-main: hsl(42, 100%, 62%);--warning-main-8-p: hsla(42, 100%, 62%, .08);--warning-main-50-p: hsla(42, 100%, 62%, .5);--warning-dark: hsl(42, 100%, 55%);--warning-darker: hsl(25, 50%, 38%);--warning-outlined-border: hsl(42, 100%, 62%);--warning-contrast-text: hsl(25, 40%, 22%);--warning-button-contrast-text: hsl(24, 40%, 22%);--error-lighter: hsl(0, 100%, 96.8%);--error-light: hsl(0, 90.2%, 91.9%);--error-main: hsl(358, 75%, 59%);--error-main-8-p: hsla(358, 75%, 59%, .08);--error-main-50-p: hsla(358, 75%, 59%, .5);--error-dark: hsl(358, 67.4%, 54.6%);--error-darker: hsl(358, 65%, 47%);--error-outlined-border: hsl(358, 75%, 59%);--error-contrast-text: hsl(350, 63%, 24%);--error-button-contrast-text: hsl(0, 0%, 100%);--aba: #FFC134;--abb: #4F4FF5}.fusion-v4[_ngcontent-%COMP%]{--spacing-tockenset: 0px;--spacing-25: 2px;--spacing-50: 4px;--spacing-75: 6px;--spacing-100: 8px;--spacing-125: 10px;--spacing-150: 12px;--spacing-200: 16px;--spacing-250: 20px;--spacing-300: 24px;--spacing-400: 32px;--spacing-500: 40px;--spacing-600: 48px;--spacing-700: 56px;--spacing-800: 64px;--spacing-900: 72px;--spacing-1000: 80px}.fusion-v4[_ngcontent-%COMP%]{--border-radius-xs: 2px;--border-radius-sm: 4px;--border-radius-md: 6px;--border-radius-lg: 8px;--border-radius-xl: 16px;--border-radius-full: 100px}.font-v4-bold[_ngcontent-%COMP%], .font-v4-tab-label-2[_ngcontent-%COMP%], .font-v4-chart-2[_ngcontent-%COMP%], .font-v4-chart-1[_ngcontent-%COMP%]{font-family:Inter,sans-serif;font-weight:700;-webkit-font-smoothing:antialiased}.font-v4-semibold[_ngcontent-%COMP%], .font-v4-chip-label[_ngcontent-%COMP%], .font-v4-table-label[_ngcontent-%COMP%], [_nghost-%COMP%]   button[_ngcontent-%COMP%], .font-v4-button[_ngcontent-%COMP%], .font-v4-heading-6[_ngcontent-%COMP%], .font-v4-heading-5[_ngcontent-%COMP%], .font-v4-heading-4[_ngcontent-%COMP%], .font-v4-heading-3[_ngcontent-%COMP%], .font-v4-heading-2[_ngcontent-%COMP%], .font-v4-heading-1[_ngcontent-%COMP%], .font-v4-title[_ngcontent-%COMP%]{font-family:Inter,sans-serif;font-weight:600;-webkit-font-smoothing:antialiased}.font-v4-medium[_ngcontent-%COMP%], .font-v4-tab-label-1[_ngcontent-%COMP%], .font-v4-input-label[_ngcontent-%COMP%], .font-v4-overline[_ngcontent-%COMP%], .font-v4-subtitle-2[_ngcontent-%COMP%], .font-v4-subtitle-1[_ngcontent-%COMP%]{font-family:Inter,sans-serif;font-weight:500;-webkit-font-smoothing:antialiased}.font-v4-regular[_ngcontent-%COMP%], .font-v4-caption[_ngcontent-%COMP%], .font-v4-body-2[_ngcontent-%COMP%], .font-v4-body-1[_ngcontent-%COMP%]{font-family:Inter,sans-serif;font-weight:400;-webkit-font-smoothing:antialiased}.font-v4-title[_ngcontent-%COMP%]{font-size:2.5rem;line-height:3rem;letter-spacing:-.055rem}.font-v4-heading-1[_ngcontent-%COMP%]{font-size:1.5rem;line-height:1.75rem;letter-spacing:-.0285rem}.font-v4-heading-2[_ngcontent-%COMP%]{font-size:1.125rem;line-height:1.75rem;letter-spacing:-.01575rem}.font-v4-heading-3[_ngcontent-%COMP%]{font-size:1rem;line-height:1.5rem;letter-spacing:-.011rem}.font-v4-heading-4[_ngcontent-%COMP%]{font-size:.875rem;line-height:1rem;letter-spacing:unset}.font-v4-heading-5[_ngcontent-%COMP%]{font-size:.8125rem;line-height:16px;letter-spacing:unset}.font-v4-heading-6[_ngcontent-%COMP%]{font-size:.75rem;line-height:.75rem;letter-spacing:0}.font-v4-body-1[_ngcontent-%COMP%]{font-size:.875rem;line-height:1.25rem;letter-spacing:-.00525rem}.font-v4-body-2[_ngcontent-%COMP%]{font-size:.8125rem;line-height:1.25rem;letter-spacing:-.00244rem}.font-v4-subtitle-1[_ngcontent-%COMP%]{font-size:.875rem;line-height:1.25rem;letter-spacing:-.00525rem}.font-v4-subtitle-2[_ngcontent-%COMP%]{font-size:.8125rem;line-height:1.25rem;letter-spacing:-.00244rem}.font-v4-chart-1[_ngcontent-%COMP%]{font-size:1.5rem;line-height:1.5rem;letter-spacing:-.015rem}.font-v4-chart-2[_ngcontent-%COMP%]{font-size:1.25rem;line-height:1.25rem;letter-spacing:-.0125rem}[_nghost-%COMP%]   button[_ngcontent-%COMP%], .font-v4-button[_ngcontent-%COMP%]{font-size:.875rem;line-height:1.25rem;letter-spacing:.00875rem}.font-v4-overline[_ngcontent-%COMP%]{font-size:.75rem;line-height:1rem;letter-spacing:.045rem;text-transform:uppercase}.font-v4-caption[_ngcontent-%COMP%]{font-size:.75rem;line-height:1rem}.font-v4-table-label[_ngcontent-%COMP%]{font-size:.8125rem;line-height:1.25rem;letter-spacing:.00813rem}.font-v4-input-label[_ngcontent-%COMP%]{font-size:.8125rem;line-height:1rem;letter-spacing:.00813rem}.font-v4-tab-label-1[_ngcontent-%COMP%], .font-v4-tab-label-2[_ngcontent-%COMP%]{font-size:.875rem;line-height:1rem}.font-v4-chip-label[_ngcontent-%COMP%]{font-size:.75rem;line-height:1rem;letter-spacing:normal}[_nghost-%COMP%]{margin:0;padding:0}[_nghost-%COMP%]   button[_ngcontent-%COMP%]{box-sizing:border-box;display:flex;padding:var(--spacing-50, 4px) var(--spacing-100, 8px);justify-content:center;align-items:center;gap:var(--spacing-100, 8px);color:var(--default-button-contrast-text, hsl(0, 0%, 0%));background-color:var(--default-main, hsl(0, 0%, 94.51%));border:none;border-radius:var(--border-radius-md, 6px);transition:background-color .2s ease;position:relative}[_nghost-%COMP%]   button[_ngcontent-%COMP%]   .fu-button-loading[_ngcontent-%COMP%]{display:none}[_nghost-%COMP%]   button[_ngcontent-%COMP%]:hover{cursor:pointer;background-color:var(--default-light, hsl(0, 0%, 89.5%));outline:none}[_nghost-%COMP%]   button.fu-outlined[_ngcontent-%COMP%]{color:var(--text-primary, hsl(0, 0%, 12.5%));border:1px solid var(--default-outlined-border, hsl(0, 0%, 73.2%));padding:calc(var(--spacing-50, 4px) - 1px) calc(var(--spacing-100, 8px) - 1px);background:none}[_nghost-%COMP%]   button.fu-outlined[_ngcontent-%COMP%]:hover{border-color:var(--action-active, hsl(0, 0%, 50.3%));background-color:var(--action-hover, hsla(0, 0%, 0%, .05))}[_nghost-%COMP%]   button.fu-text[_ngcontent-%COMP%]{color:var(--text-primary, hsl(0, 0%, 12.5%));background:none}[_nghost-%COMP%]   button.fu-text[_ngcontent-%COMP%]:hover{background-color:var(--action-hover, hsla(0, 0%, 0%, .05))}[_nghost-%COMP%]   button.fu-primary[_ngcontent-%COMP%]{color:var(--primary-button-contrast-text, hsl(0, 0%, 100%));background-color:var(--primary-main, hsl(206, 100%, 50%))}[_nghost-%COMP%]   button.fu-primary[_ngcontent-%COMP%]:hover{background-color:var(--primary-dark, hsl(208, 93.5%, 47.4%))}[_nghost-%COMP%]   button.fu-primary.fu-outlined[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-primary.fu-text[_ngcontent-%COMP%]{color:var(--primary-main, hsl(206, 100%, 50%));background:none}[_nghost-%COMP%]   button.fu-primary.fu-outlined[_ngcontent-%COMP%]:hover, [_nghost-%COMP%]   button.fu-primary.fu-text[_ngcontent-%COMP%]:hover{background-color:var(--primary-lighter, hsl(209, 100%, 96.5%))}[_nghost-%COMP%]   button.fu-primary.fu-outlined[_ngcontent-%COMP%]{border-color:var(--primary-main, hsl(206, 100%, 50%))}[_nghost-%COMP%]   button.fu-danger[_ngcontent-%COMP%]{color:var(--error-button-contrast-text, hsl(0, 0%, 100%));background-color:var(--error-main, hsl(358, 75%, 59%))}[_nghost-%COMP%]   button.fu-danger[_ngcontent-%COMP%]:hover{background-color:var(--error-dark, hsl(358, 67.4%, 54.6%))}[_nghost-%COMP%]   button.fu-danger.fu-outlined[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-danger.fu-text[_ngcontent-%COMP%]{color:var(--error-main, hsl(358, 75%, 59%));background:none}[_nghost-%COMP%]   button.fu-danger.fu-outlined[_ngcontent-%COMP%]:hover, [_nghost-%COMP%]   button.fu-danger.fu-text[_ngcontent-%COMP%]:hover{background-color:var(--error-lighter, hsl(0, 100%, 96.8%))}[_nghost-%COMP%]   button.fu-danger.fu-outlined[_ngcontent-%COMP%]{border-color:var(--error-main, hsl(358, 75%, 59%))}[_nghost-%COMP%]   button.fu-info[_ngcontent-%COMP%]{color:var(--info-button-contrast-text, hsl(0, 0%, 100%));background-color:var(--info-main, hsl(226, 70%, 55.5%))}[_nghost-%COMP%]   button.fu-info[_ngcontent-%COMP%]:hover{background-color:var(--info-dark, hsl(226, 58.6%, 51.3%))}[_nghost-%COMP%]   button.fu-info.fu-outlined[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-info.fu-text[_ngcontent-%COMP%]{color:var(--info-main, hsl(226, 70%, 55.5%));background:none}[_nghost-%COMP%]   button.fu-info.fu-outlined[_ngcontent-%COMP%]:hover, [_nghost-%COMP%]   button.fu-info.fu-text[_ngcontent-%COMP%]:hover{background-color:var(--info-lighter, hsl(223, 98.4%, 97.1%))}[_nghost-%COMP%]   button.fu-info.fu-outlined[_ngcontent-%COMP%]{border-color:var(--info-main, hsl(226, 70%, 55.5%))}[_nghost-%COMP%]   button.fu-success[_ngcontent-%COMP%]{color:var(--success-button-contrast-text, hsl(0, 0%, 100%));background-color:var(--success-main, hsl(151, 55%, 41.5%))}[_nghost-%COMP%]   button.fu-success[_ngcontent-%COMP%]:hover{background-color:var(--success-dark, hsl(152, 57.5%, 37.6%))}[_nghost-%COMP%]   button.fu-success.fu-outlined[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-success.fu-text[_ngcontent-%COMP%]{color:var(--success-main, hsl(151, 55%, 41.5%));background:none}[_nghost-%COMP%]   button.fu-success.fu-outlined[_ngcontent-%COMP%]:hover, [_nghost-%COMP%]   button.fu-success.fu-text[_ngcontent-%COMP%]:hover{background-color:var(--success-lighter, hsl(139, 55.2%, 94.5%))}[_nghost-%COMP%]   button.fu-success.fu-outlined[_ngcontent-%COMP%]{border-color:var(--success-main, hsl(151, 55%, 41.5%))}[_nghost-%COMP%]   button.fu-warning[_ngcontent-%COMP%]{color:var(--warning-button-contrast-text, hsl(24, 40%, 22%));background-color:var(--warning-main, hsl(42, 100%, 62%))}[_nghost-%COMP%]   button.fu-warning[_ngcontent-%COMP%]:hover{background-color:var(--warning-dark, hsl(42, 100%, 55%))}[_nghost-%COMP%]   button.fu-warning.fu-outlined[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-warning.fu-text[_ngcontent-%COMP%]{color:var(--warning-darker, hsl(25, 50%, 38%));background:none}[_nghost-%COMP%]   button.fu-warning.fu-outlined[_ngcontent-%COMP%]:hover, [_nghost-%COMP%]   button.fu-warning.fu-text[_ngcontent-%COMP%]:hover{background-color:var(--warning-lighter, hsl(45, 100%, 90.8%))}[_nghost-%COMP%]   button.fu-warning.fu-outlined[_ngcontent-%COMP%]{border-color:var(--warning-darker, hsl(25, 50%, 38%))}[_nghost-%COMP%]   button.fu-small[_ngcontent-%COMP%]{padding:var(--spacing-25, 2px) var(--spacing-75, 6px)}[_nghost-%COMP%]   button.fu-large[_ngcontent-%COMP%]{padding:var(--spacing-75, 6px) var(--spacing-100, 8px)}[_nghost-%COMP%]   button.fu-extraLarge[_ngcontent-%COMP%]{padding:var(--spacing-125, 10px) var(--spacing-150, 12px)}[_nghost-%COMP%]   button.fu-outlined.fu-small[_ngcontent-%COMP%]{padding:calc(var(--spacing-25, 2px) - 1px) calc(var(--spacing-75, 6px) - 1px)}[_nghost-%COMP%]   button.fu-outlined.fu-large[_ngcontent-%COMP%]{padding:calc(var(--spacing-75, 6px) - 1px) calc(var(--spacing-100, 8px) - 1px)}[_nghost-%COMP%]   button.fu-outlined.fu-extraLarge[_ngcontent-%COMP%]{padding:calc(var(--spacing-125, 10px) - 1px) calc(var(--spacing-150, 12px) - 1px)}[_nghost-%COMP%]   button[_ngcontent-%COMP%]:disabled{cursor:default;color:var(--text-disabled, hsl(0, 0%, 73.33%));background-color:var(--action-disabled-background, hsl(0, 0%, 95%))}[_nghost-%COMP%]   button[_ngcontent-%COMP%]:disabled:hover{background-color:var(--action-disabled-background, hsl(0, 0%, 95%))}[_nghost-%COMP%]   button.fu-outlined[_ngcontent-%COMP%]:disabled{color:var(--text-disabled, hsl(0, 0%, 73.33%));border-color:var(--default-outlined-border, hsl(0, 0%, 73.2%));background:none!important}[_nghost-%COMP%]   button.fu-outlined[_ngcontent-%COMP%]:disabled:hover{background-color:var(--action-disabled-background, hsl(0, 0%, 95%))}[_nghost-%COMP%]   button.fu-text[_ngcontent-%COMP%]:disabled{background:none;color:var(--text-disabled, hsl(0, 0%, 73.33%))}[_nghost-%COMP%]   button.fu-text[_ngcontent-%COMP%]:disabled:hover{background:none}[_nghost-%COMP%]   button.fu-loading[_ngcontent-%COMP%]   .fu-button-content[_ngcontent-%COMP%]{visibility:hidden}[_nghost-%COMP%]   button.fu-loading[_ngcontent-%COMP%]   .fu-button-loading[_ngcontent-%COMP%]{display:block;position:absolute}[_nghost-%COMP%]   button.fu-loading[_ngcontent-%COMP%]   .fu-button-start-icon[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-loading[_ngcontent-%COMP%]   .fu-button-end-icon[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-loading[_ngcontent-%COMP%]   .fu-button-icon[_ngcontent-%COMP%]{visibility:hidden}[_nghost-%COMP%]   button.fu-outlined.fu-loading[_ngcontent-%COMP%]:disabled{background:var(--action-disabled-background, hsl(0, 0%, 95%))}[_nghost-%COMP%]   button[_ngcontent-%COMP%]   .fu-button-start-icon[_ngcontent-%COMP%], [_nghost-%COMP%]   button[_ngcontent-%COMP%]   .fu-button-end-icon[_ngcontent-%COMP%]{width:16px;height:16px}[_nghost-%COMP%]   button.fu-selected[_ngcontent-%COMP%]{border-width:2px;border-color:var(--action-active, hsl(0, 0%, 50.3%));background-color:var(--action-selected, hsl(0, 0%, 92%));padding:2px 6px}[_nghost-%COMP%]   button.fu-selected.fu-small[_ngcontent-%COMP%]{padding:0 4px}[_nghost-%COMP%]   button.fu-selected.fu-large[_ngcontent-%COMP%]{padding:4px 6px}[_nghost-%COMP%]   button.fu-selected.fu-extraLarge[_ngcontent-%COMP%]{padding:8px 10px}", ".fusion-v4[_ngcontent-%COMP%]{--spacing-tockenset: 0px;--spacing-25: 2px;--spacing-50: 4px;--spacing-75: 6px;--spacing-100: 8px;--spacing-125: 10px;--spacing-150: 12px;--spacing-200: 16px;--spacing-250: 20px;--spacing-300: 24px;--spacing-400: 32px;--spacing-500: 40px;--spacing-600: 48px;--spacing-700: 56px;--spacing-800: 64px;--spacing-900: 72px;--spacing-1000: 80px}.fusion-v4[_ngcontent-%COMP%]{--background-default: #FFFFFF;--background-paper: hsl(0, 0%, 99%);--background-model-elevation: #FFFFFF;--background-backdrop: hsla(0, 0%, 0%, .11);--background-paper-elevation-0: hsl(0, 0%, 97.5%);--background-paper-elevation-1: hsl(0, 0%, 94.6%);--background-paper-elevation-2: hsl(0, 0%, 92%);--background-paper-elevation-3: hsl(0, 0%, 89.5%);--background-paper-elevation-4: hsl(0, 0%, 86.8%);--background-paper-elevation-5: hsl(0, 0%, 83%);--background-paper-elevation-6: hsl(0, 0%, 73.2%);--background-paper-elevation-7: hsl(0, 0%, 55.2%);--background-paper-elevation-8: hsl(0, 0%, 50.3%);--background-paper-elevation-9: hsl(0, 0%, 39.3%);--action-primary: hsl(0, 0%, 12.5%);--action-active: hsl(0, 0%, 50.3%);--action-hover: hsla(0, 0%, 0%, .05);--action-selected: hsl(0, 0%, 92%);--action-disabled: hsl(0, 0%, 87%);--action-disabled-background: hsl(0, 0%, 95%);--action-focus: hsl(0, 0%, 92%);--action-outlined-border: hsl(0, 0%, 73%);--default-light: hsl(0, 0%, 89.5%);--default-main: hsl(0, 0%, 94.51%);--default-dark: hsl(0, 0%, 92%);--default-outlined-border: hsl(0, 0%, 73.2%);--default-contrast-text: hsl(0, 0%, 12.5%);--default-button-contrast-text: hsl(0, 0%, 0%);--common-white: #FFFFFF;--common-black: #000000;--common-inverse-white: #FFFFFF;--common-inverse-black: #000000;--common-divider: hsl(0, 0%, 86.8%);--common-divider-elevation-0: hsl(0, 0%, 89%);--text-primary: hsl(0, 0%, 12.5%);--text-secondary: hsl(0, 0%, 39.3%);--text-disabled: hsl(0, 0%, 73.33%);--primary-lighter: hsl(209, 100%, 96.5%);--primary-light: hsl(209, 95%, 90.1%);--primary-main: hsl(206, 100%, 50%);--primary-main-8-p: hsla(206, 100%, 50%, .08);--primary-main-50-p: hsla(206, 100%, 50%, .5);--primary-dark: hsl(208, 93.5%, 47.4%);--primary-darker: hsl(211, 90%, 42%);--primary-outlined-border: hsl(206, 100%, 50%);--primary-contrast-text: hsl(216, 71%, 23%);--primary-button-contrast-text: hsl(0, 0%, 100%);--info-lighter: hsl(223, 98.4%, 97.1%);--info-light: hsl(224, 87.1%, 92%);--info-main: hsl(226, 70%, 55.5%);--info-main-8-p: hsla(226, 70%, 55.5%, .08);--info-main-50-p: hsla(226, 70%, 55.5%, .5);--info-dark: hsl(226, 58.6%, 51.3%);--info-darker: hsl(226, 55%, 45%);--info-outlined-border: hsl(226, 70%, 55.5%);--info-contrast-text: hsl(226, 50%, 24%);--info-button-contrast-text: hsl(0, 0%, 100%);--success-lighter: hsl(139, 55.2%, 94.5%);--success-light: hsl(141, 43.7%, 86%);--success-main: hsl(151, 55%, 41.5%);--success-main-8-p: hsla(151, 55%, 41.5%, .08);--success-main-50-p: hsla(151, 55%, 41.5%, .5);--success-dark: hsl(152, 57.5%, 37.6%);--success-darker: hsl(153, 67%, 28.5%);--success-outlined-border: hsl(151, 55%, 41.5%);--success-contrast-text: hsl(155, 40%, 16.5%);--success-button-contrast-text: hsl(0, 0%, 100%);--warning-lighter: hsl(45, 100%, 90.8%);--warning-light: hsl(40, 100%, 81.5%);--warning-main: hsl(42, 100%, 62%);--warning-main-8-p: hsla(42, 100%, 62%, .08);--warning-main-50-p: hsla(42, 100%, 62%, .5);--warning-dark: hsl(42, 100%, 55%);--warning-darker: hsl(25, 50%, 38%);--warning-outlined-border: hsl(42, 100%, 62%);--warning-contrast-text: hsl(25, 40%, 22%);--warning-button-contrast-text: hsl(24, 40%, 22%);--error-lighter: hsl(0, 100%, 96.8%);--error-light: hsl(0, 90.2%, 91.9%);--error-main: hsl(358, 75%, 59%);--error-main-8-p: hsla(358, 75%, 59%, .08);--error-main-50-p: hsla(358, 75%, 59%, .5);--error-dark: hsl(358, 67.4%, 54.6%);--error-darker: hsl(358, 65%, 47%);--error-outlined-border: hsl(358, 75%, 59%);--error-contrast-text: hsl(350, 63%, 24%);--error-button-contrast-text: hsl(0, 0%, 100%);--aba: #FFC134;--abb: #4F4FF5}[_nghost-%COMP%]{margin:0;padding:0;display:inline-block}[_nghost-%COMP%]   button.fu-default[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-primary[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-danger[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-info[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-success[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-warning[_ngcontent-%COMP%]{padding:var(--spacing-50, 4px);gap:0}[_nghost-%COMP%]   button.fu-default[_ngcontent-%COMP%]   .fu-button-icon[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-primary[_ngcontent-%COMP%]   .fu-button-icon[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-danger[_ngcontent-%COMP%]   .fu-button-icon[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-info[_ngcontent-%COMP%]   .fu-button-icon[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-success[_ngcontent-%COMP%]   .fu-button-icon[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-warning[_ngcontent-%COMP%]   .fu-button-icon[_ngcontent-%COMP%]{width:20px;height:20px}[_nghost-%COMP%]   button.fu-default[_ngcontent-%COMP%]{color:var(--action-active, hsl(0, 0%, 50.3%));background-color:transparent}[_nghost-%COMP%]   button.fu-default[_ngcontent-%COMP%]:hover{color:var(--default-contrast-text, hsl(0, 0%, 12.5%));background-color:var(--action-hover, hsla(0, 0%, 0%, .05))}[_nghost-%COMP%]   button.fu-default.fu-outlined[_ngcontent-%COMP%]{padding:calc(var(--spacing-50, 4px) - 1px);color:var(--action-active, hsl(0, 0%, 50.3%));border-color:var(--action-outlined-border, hsl(0, 0%, 73%))}[_nghost-%COMP%]   button.fu-default.fu-outlined[_ngcontent-%COMP%]:hover{color:var(--default-contrast-text, hsl(0, 0%, 12.5%));border-color:var(--action-active, hsl(0, 0%, 50.3%));background-color:var(--action-hover, hsla(0, 0%, 0%, .05))}[_nghost-%COMP%]   button.fu-default.fu-outlined[_ngcontent-%COMP%]:disabled{border-color:var(--action-disabled, hsl(0, 0%, 87%))}[_nghost-%COMP%]   button.fu-default[_ngcontent-%COMP%]:disabled{color:var(--action-disabled, hsl(0, 0%, 87%))}[_nghost-%COMP%]   button.fu-default[_ngcontent-%COMP%]:disabled:hover{color:var(--action-disabled, hsl(0, 0%, 87%));background-color:transparent}[_nghost-%COMP%]   button.fu-primary[_ngcontent-%COMP%]{color:var(--primary-main, hsl(206, 100%, 50%));background-color:transparent}[_nghost-%COMP%]   button.fu-primary[_ngcontent-%COMP%]:hover{color:var(--primary-main, hsl(206, 100%, 50%));background-color:var(--primary-main-8-p, hsla(206, 100%, 50%, .08))}[_nghost-%COMP%]   button.fu-primary.fu-outlined[_ngcontent-%COMP%]{padding:calc(var(--spacing-50, 4px) - 1px);color:var(--primary-main, hsl(206, 100%, 50%));border-color:var(--primary-main, hsl(206, 100%, 50%))}[_nghost-%COMP%]   button.fu-primary.fu-outlined[_ngcontent-%COMP%]:hover{color:var(--primary-main, hsl(206, 100%, 50%));border-color:var(--primary-main, hsl(206, 100%, 50%));background-color:var(--primary-main-8-p, hsla(206, 100%, 50%, .08))}[_nghost-%COMP%]   button.fu-primary.fu-outlined[_ngcontent-%COMP%]:disabled{color:var(--action-disabled, hsl(0, 0%, 87%));border-color:var(--action-disabled, hsl(0, 0%, 87%))}[_nghost-%COMP%]   button.fu-danger[_ngcontent-%COMP%]{color:var(--error-main, hsl(358, 75%, 59%));background-color:transparent}[_nghost-%COMP%]   button.fu-danger[_ngcontent-%COMP%]:hover{color:var(--error-main, hsl(358, 75%, 59%));background-color:var(--error-main-8-p, hsla(358, 75%, 59%, .08))}[_nghost-%COMP%]   button.fu-danger.fu-outlined[_ngcontent-%COMP%]{padding:calc(var(--spacing-50, 4px) - 1px);color:var(--error-main, hsl(358, 75%, 59%));border-color:var(--error-main, hsl(358, 75%, 59%))}[_nghost-%COMP%]   button.fu-danger.fu-outlined[_ngcontent-%COMP%]:hover{color:var(--error-main, hsl(358, 75%, 59%));border-color:var(--error-main, hsl(358, 75%, 59%));background-color:var(--error-main-8-p, hsla(358, 75%, 59%, .08))}[_nghost-%COMP%]   button.fu-danger.fu-outlined[_ngcontent-%COMP%]:disabled{color:var(--action-disabled, hsl(0, 0%, 87%));border-color:var(--action-disabled, hsl(0, 0%, 87%))}[_nghost-%COMP%]   button.fu-info[_ngcontent-%COMP%]{color:var(--info-main, hsl(226, 70%, 55.5%));background-color:transparent}[_nghost-%COMP%]   button.fu-info[_ngcontent-%COMP%]:hover{color:var(--info-main, hsl(226, 70%, 55.5%));background-color:var(--info-main-8-p, hsla(226, 70%, 55.5%, .08))}[_nghost-%COMP%]   button.fu-info.fu-outlined[_ngcontent-%COMP%]{padding:calc(var(--spacing-50, 4px) - 1px);color:var(--info-main, hsl(226, 70%, 55.5%));border-color:var(--info-main, hsl(226, 70%, 55.5%))}[_nghost-%COMP%]   button.fu-info.fu-outlined[_ngcontent-%COMP%]:hover{color:var(--info-main, hsl(226, 70%, 55.5%));border-color:var(--info-main, hsl(226, 70%, 55.5%));background-color:var(--info-main-8-p, hsla(226, 70%, 55.5%, .08))}[_nghost-%COMP%]   button.fu-info.fu-outlined[_ngcontent-%COMP%]:disabled{color:var(--action-disabled, hsl(0, 0%, 87%));border-color:var(--action-disabled, hsl(0, 0%, 87%))}[_nghost-%COMP%]   button.fu-success[_ngcontent-%COMP%]{color:var(--success-main, hsl(151, 55%, 41.5%));background-color:transparent}[_nghost-%COMP%]   button.fu-success[_ngcontent-%COMP%]:hover{color:var(--success-main, hsl(151, 55%, 41.5%));background-color:var(--success-main-8-p, hsla(151, 55%, 41.5%, .08))}[_nghost-%COMP%]   button.fu-success.fu-outlined[_ngcontent-%COMP%]{padding:calc(var(--spacing-50, 4px) - 1px);color:var(--success-main, hsl(151, 55%, 41.5%));border-color:var(--success-main, hsl(151, 55%, 41.5%))}[_nghost-%COMP%]   button.fu-success.fu-outlined[_ngcontent-%COMP%]:hover{color:var(--success-main, hsl(151, 55%, 41.5%));border-color:var(--success-main, hsl(151, 55%, 41.5%));background-color:var(--success-main-8-p, hsla(151, 55%, 41.5%, .08))}[_nghost-%COMP%]   button.fu-success.fu-outlined[_ngcontent-%COMP%]:disabled{color:var(--action-disabled, hsl(0, 0%, 87%));border-color:var(--action-disabled, hsl(0, 0%, 87%))}[_nghost-%COMP%]   button.fu-warning[_ngcontent-%COMP%]{color:var(--warning-main, hsl(42, 100%, 62%));background-color:transparent}[_nghost-%COMP%]   button.fu-warning[_ngcontent-%COMP%]:hover{color:var(--warning-main, hsl(42, 100%, 62%));background-color:var(--warning-main-8-p, hsla(42, 100%, 62%, .08))}[_nghost-%COMP%]   button.fu-warning.fu-outlined[_ngcontent-%COMP%]{padding:calc(var(--spacing-50, 4px) - 1px);color:var(--warning-main, hsl(42, 100%, 62%));border-color:var(--warning-main, hsl(42, 100%, 62%))}[_nghost-%COMP%]   button.fu-warning.fu-outlined[_ngcontent-%COMP%]:hover{color:var(--warning-main, hsl(42, 100%, 62%));border-color:var(--warning-main, hsl(42, 100%, 62%));background-color:var(--warning-main-8-p, hsla(42, 100%, 62%, .08))}[_nghost-%COMP%]   button.fu-warning.fu-outlined[_ngcontent-%COMP%]:disabled{color:var(--action-disabled, hsl(0, 0%, 87%));border-color:var(--action-disabled, hsl(0, 0%, 87%))}[_nghost-%COMP%]   button.fu-extraSmall[_ngcontent-%COMP%]{padding:var(--spacing-25, 2px)}[_nghost-%COMP%]   button.fu-extraSmall.fu-outlined[_ngcontent-%COMP%]{padding:calc(var(--spacing-25, 2px) - 1px)}[_nghost-%COMP%]   button.fu-extraSmall[_ngcontent-%COMP%]   .fu-button-icon[_ngcontent-%COMP%]{width:16px;height:16px}[_nghost-%COMP%]   button.fu-small[_ngcontent-%COMP%]{padding:var(--spacing-25, 2px)}[_nghost-%COMP%]   button.fu-small.fu-outlined[_ngcontent-%COMP%]{padding:calc(var(--spacing-25, 2px) - 1px)}[_nghost-%COMP%]   button.fu-large[_ngcontent-%COMP%]{padding:var(--spacing-50, 4px)}[_nghost-%COMP%]   button.fu-large.fu-outlined[_ngcontent-%COMP%]{padding:calc(var(--spacing-50, 4px) - 1px)}[_nghost-%COMP%]   button.fu-extraLarge[_ngcontent-%COMP%]{padding:var(--spacing-100, 8px)}[_nghost-%COMP%]   button.fu-extraLarge.fu-outlined[_ngcontent-%COMP%]{padding:calc(var(--spacing-100, 8px) - 1px)}[_nghost-%COMP%]   button.fu-large[_ngcontent-%COMP%]   .fu-button-icon[_ngcontent-%COMP%], [_nghost-%COMP%]   button.fu-extraLarge[_ngcontent-%COMP%]   .fu-button-icon[_ngcontent-%COMP%]{width:24px;height:24px}"], changeDetection: 0 }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(IconButtonComponent, [{
        type: Component,
        args: [{ selector: 'fusion-icon-button', standalone: true, imports: [CommonModule, IconModule, LoaderComponent, GenericPipe], host: { class: 'fusion-v4' }, changeDetection: ChangeDetectionStrategy.OnPush, template: "<button [class]=\"buttonClass\" [class.fu-selected]=\"selected\" [class.fu-loading]=\"loading\"\n        [disabled]=\"disabled || loading\" [attr.data-testid]=\"testId\">\n    <fusion-icon *ngIf=\"startIconName\" [style.color]=\"startIconColor\" class=\"fu-button-start-icon\"\n                 [name]=\"startIconName\"\n                 [attr.data-testid]=\"testIdsService.getTestAttribute.bind(this) | generic:testId:testIdButtonModifiers.ICON\"></fusion-icon>\n    <fusion-icon *ngIf=\"iconName\" class=\"fu-button-icon\" [name]=\"iconName\"\n                 [attr.data-testid]=\"testIdsService.getTestAttribute.bind(this) | generic:testId:testIdButtonModifiers.ICON\"></fusion-icon>\n    <div *ngIf=\"!iconName\" class=\"fu-button-content\"\n         [attr.data-testid]=\"testIdsService.getTestAttribute.bind(this) | generic:testId:testIdButtonModifiers.CONTENT\">\n        <ng-content></ng-content>\n    </div>\n    <fusion-icon *ngIf=\"endIconName\" [style.color]=\"endIconColor\" class=\"fu-button-end-icon\" [name]=\"endIconName\"\n                 [attr.data-testid]=\"testIdsService.getTestAttribute.bind(this) | generic:testId:testIdButtonModifiers.ICON\"></fusion-icon>\n    <div class=\"fu-button-loading\">\n        <fusion-loader\n            [attr.data-testid]=\"testIdsService.getTestAttribute.bind(this) | generic:testId:testIdButtonModifiers.LOADER\"\n            style=\"width: 16px; height: 16px\"></fusion-loader>\n    </div>\n</button>\n", styles: ["@import\"https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600;700&display=swap\";.fusion-v4{--background-default: #FFFFFF;--background-paper: hsl(0, 0%, 99%);--background-model-elevation: #FFFFFF;--background-backdrop: hsla(0, 0%, 0%, .11);--background-paper-elevation-0: hsl(0, 0%, 97.5%);--background-paper-elevation-1: hsl(0, 0%, 94.6%);--background-paper-elevation-2: hsl(0, 0%, 92%);--background-paper-elevation-3: hsl(0, 0%, 89.5%);--background-paper-elevation-4: hsl(0, 0%, 86.8%);--background-paper-elevation-5: hsl(0, 0%, 83%);--background-paper-elevation-6: hsl(0, 0%, 73.2%);--background-paper-elevation-7: hsl(0, 0%, 55.2%);--background-paper-elevation-8: hsl(0, 0%, 50.3%);--background-paper-elevation-9: hsl(0, 0%, 39.3%);--action-primary: hsl(0, 0%, 12.5%);--action-active: hsl(0, 0%, 50.3%);--action-hover: hsla(0, 0%, 0%, .05);--action-selected: hsl(0, 0%, 92%);--action-disabled: hsl(0, 0%, 87%);--action-disabled-background: hsl(0, 0%, 95%);--action-focus: hsl(0, 0%, 92%);--action-outlined-border: hsl(0, 0%, 73%);--default-light: hsl(0, 0%, 89.5%);--default-main: hsl(0, 0%, 94.51%);--default-dark: hsl(0, 0%, 92%);--default-outlined-border: hsl(0, 0%, 73.2%);--default-contrast-text: hsl(0, 0%, 12.5%);--default-button-contrast-text: hsl(0, 0%, 0%);--common-white: #FFFFFF;--common-black: #000000;--common-inverse-white: #FFFFFF;--common-inverse-black: #000000;--common-divider: hsl(0, 0%, 86.8%);--common-divider-elevation-0: hsl(0, 0%, 89%);--text-primary: hsl(0, 0%, 12.5%);--text-secondary: hsl(0, 0%, 39.3%);--text-disabled: hsl(0, 0%, 73.33%);--primary-lighter: hsl(209, 100%, 96.5%);--primary-light: hsl(209, 95%, 90.1%);--primary-main: hsl(206, 100%, 50%);--primary-main-8-p: hsla(206, 100%, 50%, .08);--primary-main-50-p: hsla(206, 100%, 50%, .5);--primary-dark: hsl(208, 93.5%, 47.4%);--primary-darker: hsl(211, 90%, 42%);--primary-outlined-border: hsl(206, 100%, 50%);--primary-contrast-text: hsl(216, 71%, 23%);--primary-button-contrast-text: hsl(0, 0%, 100%);--info-lighter: hsl(223, 98.4%, 97.1%);--info-light: hsl(224, 87.1%, 92%);--info-main: hsl(226, 70%, 55.5%);--info-main-8-p: hsla(226, 70%, 55.5%, .08);--info-main-50-p: hsla(226, 70%, 55.5%, .5);--info-dark: hsl(226, 58.6%, 51.3%);--info-darker: hsl(226, 55%, 45%);--info-outlined-border: hsl(226, 70%, 55.5%);--info-contrast-text: hsl(226, 50%, 24%);--info-button-contrast-text: hsl(0, 0%, 100%);--success-lighter: hsl(139, 55.2%, 94.5%);--success-light: hsl(141, 43.7%, 86%);--success-main: hsl(151, 55%, 41.5%);--success-main-8-p: hsla(151, 55%, 41.5%, .08);--success-main-50-p: hsla(151, 55%, 41.5%, .5);--success-dark: hsl(152, 57.5%, 37.6%);--success-darker: hsl(153, 67%, 28.5%);--success-outlined-border: hsl(151, 55%, 41.5%);--success-contrast-text: hsl(155, 40%, 16.5%);--success-button-contrast-text: hsl(0, 0%, 100%);--warning-lighter: hsl(45, 100%, 90.8%);--warning-light: hsl(40, 100%, 81.5%);--warning-main: hsl(42, 100%, 62%);--warning-main-8-p: hsla(42, 100%, 62%, .08);--warning-main-50-p: hsla(42, 100%, 62%, .5);--warning-dark: hsl(42, 100%, 55%);--warning-darker: hsl(25, 50%, 38%);--warning-outlined-border: hsl(42, 100%, 62%);--warning-contrast-text: hsl(25, 40%, 22%);--warning-button-contrast-text: hsl(24, 40%, 22%);--error-lighter: hsl(0, 100%, 96.8%);--error-light: hsl(0, 90.2%, 91.9%);--error-main: hsl(358, 75%, 59%);--error-main-8-p: hsla(358, 75%, 59%, .08);--error-main-50-p: hsla(358, 75%, 59%, .5);--error-dark: hsl(358, 67.4%, 54.6%);--error-darker: hsl(358, 65%, 47%);--error-outlined-border: hsl(358, 75%, 59%);--error-contrast-text: hsl(350, 63%, 24%);--error-button-contrast-text: hsl(0, 0%, 100%);--aba: #FFC134;--abb: #4F4FF5}.fusion-v4{--spacing-tockenset: 0px;--spacing-25: 2px;--spacing-50: 4px;--spacing-75: 6px;--spacing-100: 8px;--spacing-125: 10px;--spacing-150: 12px;--spacing-200: 16px;--spacing-250: 20px;--spacing-300: 24px;--spacing-400: 32px;--spacing-500: 40px;--spacing-600: 48px;--spacing-700: 56px;--spacing-800: 64px;--spacing-900: 72px;--spacing-1000: 80px}.fusion-v4{--border-radius-xs: 2px;--border-radius-sm: 4px;--border-radius-md: 6px;--border-radius-lg: 8px;--border-radius-xl: 16px;--border-radius-full: 100px}.font-v4-bold,.font-v4-tab-label-2,.font-v4-chart-2,.font-v4-chart-1{font-family:Inter,sans-serif;font-weight:700;-webkit-font-smoothing:antialiased}.font-v4-semibold,.font-v4-chip-label,.font-v4-table-label,:host button,.font-v4-button,.font-v4-heading-6,.font-v4-heading-5,.font-v4-heading-4,.font-v4-heading-3,.font-v4-heading-2,.font-v4-heading-1,.font-v4-title{font-family:Inter,sans-serif;font-weight:600;-webkit-font-smoothing:antialiased}.font-v4-medium,.font-v4-tab-label-1,.font-v4-input-label,.font-v4-overline,.font-v4-subtitle-2,.font-v4-subtitle-1{font-family:Inter,sans-serif;font-weight:500;-webkit-font-smoothing:antialiased}.font-v4-regular,.font-v4-caption,.font-v4-body-2,.font-v4-body-1{font-family:Inter,sans-serif;font-weight:400;-webkit-font-smoothing:antialiased}.font-v4-title{font-size:2.5rem;line-height:3rem;letter-spacing:-.055rem}.font-v4-heading-1{font-size:1.5rem;line-height:1.75rem;letter-spacing:-.0285rem}.font-v4-heading-2{font-size:1.125rem;line-height:1.75rem;letter-spacing:-.01575rem}.font-v4-heading-3{font-size:1rem;line-height:1.5rem;letter-spacing:-.011rem}.font-v4-heading-4{font-size:.875rem;line-height:1rem;letter-spacing:unset}.font-v4-heading-5{font-size:.8125rem;line-height:16px;letter-spacing:unset}.font-v4-heading-6{font-size:.75rem;line-height:.75rem;letter-spacing:0}.font-v4-body-1{font-size:.875rem;line-height:1.25rem;letter-spacing:-.00525rem}.font-v4-body-2{font-size:.8125rem;line-height:1.25rem;letter-spacing:-.00244rem}.font-v4-subtitle-1{font-size:.875rem;line-height:1.25rem;letter-spacing:-.00525rem}.font-v4-subtitle-2{font-size:.8125rem;line-height:1.25rem;letter-spacing:-.00244rem}.font-v4-chart-1{font-size:1.5rem;line-height:1.5rem;letter-spacing:-.015rem}.font-v4-chart-2{font-size:1.25rem;line-height:1.25rem;letter-spacing:-.0125rem}:host button,.font-v4-button{font-size:.875rem;line-height:1.25rem;letter-spacing:.00875rem}.font-v4-overline{font-size:.75rem;line-height:1rem;letter-spacing:.045rem;text-transform:uppercase}.font-v4-caption{font-size:.75rem;line-height:1rem}.font-v4-table-label{font-size:.8125rem;line-height:1.25rem;letter-spacing:.00813rem}.font-v4-input-label{font-size:.8125rem;line-height:1rem;letter-spacing:.00813rem}.font-v4-tab-label-1,.font-v4-tab-label-2{font-size:.875rem;line-height:1rem}.font-v4-chip-label{font-size:.75rem;line-height:1rem;letter-spacing:normal}:host{margin:0;padding:0}:host button{box-sizing:border-box;display:flex;padding:var(--spacing-50, 4px) var(--spacing-100, 8px);justify-content:center;align-items:center;gap:var(--spacing-100, 8px);color:var(--default-button-contrast-text, hsl(0, 0%, 0%));background-color:var(--default-main, hsl(0, 0%, 94.51%));border:none;border-radius:var(--border-radius-md, 6px);transition:background-color .2s ease;position:relative}:host button .fu-button-loading{display:none}:host button:hover{cursor:pointer;background-color:var(--default-light, hsl(0, 0%, 89.5%));outline:none}:host button.fu-outlined{color:var(--text-primary, hsl(0, 0%, 12.5%));border:1px solid var(--default-outlined-border, hsl(0, 0%, 73.2%));padding:calc(var(--spacing-50, 4px) - 1px) calc(var(--spacing-100, 8px) - 1px);background:none}:host button.fu-outlined:hover{border-color:var(--action-active, hsl(0, 0%, 50.3%));background-color:var(--action-hover, hsla(0, 0%, 0%, .05))}:host button.fu-text{color:var(--text-primary, hsl(0, 0%, 12.5%));background:none}:host button.fu-text:hover{background-color:var(--action-hover, hsla(0, 0%, 0%, .05))}:host button.fu-primary{color:var(--primary-button-contrast-text, hsl(0, 0%, 100%));background-color:var(--primary-main, hsl(206, 100%, 50%))}:host button.fu-primary:hover{background-color:var(--primary-dark, hsl(208, 93.5%, 47.4%))}:host button.fu-primary.fu-outlined,:host button.fu-primary.fu-text{color:var(--primary-main, hsl(206, 100%, 50%));background:none}:host button.fu-primary.fu-outlined:hover,:host button.fu-primary.fu-text:hover{background-color:var(--primary-lighter, hsl(209, 100%, 96.5%))}:host button.fu-primary.fu-outlined{border-color:var(--primary-main, hsl(206, 100%, 50%))}:host button.fu-danger{color:var(--error-button-contrast-text, hsl(0, 0%, 100%));background-color:var(--error-main, hsl(358, 75%, 59%))}:host button.fu-danger:hover{background-color:var(--error-dark, hsl(358, 67.4%, 54.6%))}:host button.fu-danger.fu-outlined,:host button.fu-danger.fu-text{color:var(--error-main, hsl(358, 75%, 59%));background:none}:host button.fu-danger.fu-outlined:hover,:host button.fu-danger.fu-text:hover{background-color:var(--error-lighter, hsl(0, 100%, 96.8%))}:host button.fu-danger.fu-outlined{border-color:var(--error-main, hsl(358, 75%, 59%))}:host button.fu-info{color:var(--info-button-contrast-text, hsl(0, 0%, 100%));background-color:var(--info-main, hsl(226, 70%, 55.5%))}:host button.fu-info:hover{background-color:var(--info-dark, hsl(226, 58.6%, 51.3%))}:host button.fu-info.fu-outlined,:host button.fu-info.fu-text{color:var(--info-main, hsl(226, 70%, 55.5%));background:none}:host button.fu-info.fu-outlined:hover,:host button.fu-info.fu-text:hover{background-color:var(--info-lighter, hsl(223, 98.4%, 97.1%))}:host button.fu-info.fu-outlined{border-color:var(--info-main, hsl(226, 70%, 55.5%))}:host button.fu-success{color:var(--success-button-contrast-text, hsl(0, 0%, 100%));background-color:var(--success-main, hsl(151, 55%, 41.5%))}:host button.fu-success:hover{background-color:var(--success-dark, hsl(152, 57.5%, 37.6%))}:host button.fu-success.fu-outlined,:host button.fu-success.fu-text{color:var(--success-main, hsl(151, 55%, 41.5%));background:none}:host button.fu-success.fu-outlined:hover,:host button.fu-success.fu-text:hover{background-color:var(--success-lighter, hsl(139, 55.2%, 94.5%))}:host button.fu-success.fu-outlined{border-color:var(--success-main, hsl(151, 55%, 41.5%))}:host button.fu-warning{color:var(--warning-button-contrast-text, hsl(24, 40%, 22%));background-color:var(--warning-main, hsl(42, 100%, 62%))}:host button.fu-warning:hover{background-color:var(--warning-dark, hsl(42, 100%, 55%))}:host button.fu-warning.fu-outlined,:host button.fu-warning.fu-text{color:var(--warning-darker, hsl(25, 50%, 38%));background:none}:host button.fu-warning.fu-outlined:hover,:host button.fu-warning.fu-text:hover{background-color:var(--warning-lighter, hsl(45, 100%, 90.8%))}:host button.fu-warning.fu-outlined{border-color:var(--warning-darker, hsl(25, 50%, 38%))}:host button.fu-small{padding:var(--spacing-25, 2px) var(--spacing-75, 6px)}:host button.fu-large{padding:var(--spacing-75, 6px) var(--spacing-100, 8px)}:host button.fu-extraLarge{padding:var(--spacing-125, 10px) var(--spacing-150, 12px)}:host button.fu-outlined.fu-small{padding:calc(var(--spacing-25, 2px) - 1px) calc(var(--spacing-75, 6px) - 1px)}:host button.fu-outlined.fu-large{padding:calc(var(--spacing-75, 6px) - 1px) calc(var(--spacing-100, 8px) - 1px)}:host button.fu-outlined.fu-extraLarge{padding:calc(var(--spacing-125, 10px) - 1px) calc(var(--spacing-150, 12px) - 1px)}:host button:disabled{cursor:default;color:var(--text-disabled, hsl(0, 0%, 73.33%));background-color:var(--action-disabled-background, hsl(0, 0%, 95%))}:host button:disabled:hover{background-color:var(--action-disabled-background, hsl(0, 0%, 95%))}:host button.fu-outlined:disabled{color:var(--text-disabled, hsl(0, 0%, 73.33%));border-color:var(--default-outlined-border, hsl(0, 0%, 73.2%));background:none!important}:host button.fu-outlined:disabled:hover{background-color:var(--action-disabled-background, hsl(0, 0%, 95%))}:host button.fu-text:disabled{background:none;color:var(--text-disabled, hsl(0, 0%, 73.33%))}:host button.fu-text:disabled:hover{background:none}:host button.fu-loading .fu-button-content{visibility:hidden}:host button.fu-loading .fu-button-loading{display:block;position:absolute}:host button.fu-loading .fu-button-start-icon,:host button.fu-loading .fu-button-end-icon,:host button.fu-loading .fu-button-icon{visibility:hidden}:host button.fu-outlined.fu-loading:disabled{background:var(--action-disabled-background, hsl(0, 0%, 95%))}:host button .fu-button-start-icon,:host button .fu-button-end-icon{width:16px;height:16px}:host button.fu-selected{border-width:2px;border-color:var(--action-active, hsl(0, 0%, 50.3%));background-color:var(--action-selected, hsl(0, 0%, 92%));padding:2px 6px}:host button.fu-selected.fu-small{padding:0 4px}:host button.fu-selected.fu-large{padding:4px 6px}:host button.fu-selected.fu-extraLarge{padding:8px 10px}\n", ".fusion-v4{--spacing-tockenset: 0px;--spacing-25: 2px;--spacing-50: 4px;--spacing-75: 6px;--spacing-100: 8px;--spacing-125: 10px;--spacing-150: 12px;--spacing-200: 16px;--spacing-250: 20px;--spacing-300: 24px;--spacing-400: 32px;--spacing-500: 40px;--spacing-600: 48px;--spacing-700: 56px;--spacing-800: 64px;--spacing-900: 72px;--spacing-1000: 80px}.fusion-v4{--background-default: #FFFFFF;--background-paper: hsl(0, 0%, 99%);--background-model-elevation: #FFFFFF;--background-backdrop: hsla(0, 0%, 0%, .11);--background-paper-elevation-0: hsl(0, 0%, 97.5%);--background-paper-elevation-1: hsl(0, 0%, 94.6%);--background-paper-elevation-2: hsl(0, 0%, 92%);--background-paper-elevation-3: hsl(0, 0%, 89.5%);--background-paper-elevation-4: hsl(0, 0%, 86.8%);--background-paper-elevation-5: hsl(0, 0%, 83%);--background-paper-elevation-6: hsl(0, 0%, 73.2%);--background-paper-elevation-7: hsl(0, 0%, 55.2%);--background-paper-elevation-8: hsl(0, 0%, 50.3%);--background-paper-elevation-9: hsl(0, 0%, 39.3%);--action-primary: hsl(0, 0%, 12.5%);--action-active: hsl(0, 0%, 50.3%);--action-hover: hsla(0, 0%, 0%, .05);--action-selected: hsl(0, 0%, 92%);--action-disabled: hsl(0, 0%, 87%);--action-disabled-background: hsl(0, 0%, 95%);--action-focus: hsl(0, 0%, 92%);--action-outlined-border: hsl(0, 0%, 73%);--default-light: hsl(0, 0%, 89.5%);--default-main: hsl(0, 0%, 94.51%);--default-dark: hsl(0, 0%, 92%);--default-outlined-border: hsl(0, 0%, 73.2%);--default-contrast-text: hsl(0, 0%, 12.5%);--default-button-contrast-text: hsl(0, 0%, 0%);--common-white: #FFFFFF;--common-black: #000000;--common-inverse-white: #FFFFFF;--common-inverse-black: #000000;--common-divider: hsl(0, 0%, 86.8%);--common-divider-elevation-0: hsl(0, 0%, 89%);--text-primary: hsl(0, 0%, 12.5%);--text-secondary: hsl(0, 0%, 39.3%);--text-disabled: hsl(0, 0%, 73.33%);--primary-lighter: hsl(209, 100%, 96.5%);--primary-light: hsl(209, 95%, 90.1%);--primary-main: hsl(206, 100%, 50%);--primary-main-8-p: hsla(206, 100%, 50%, .08);--primary-main-50-p: hsla(206, 100%, 50%, .5);--primary-dark: hsl(208, 93.5%, 47.4%);--primary-darker: hsl(211, 90%, 42%);--primary-outlined-border: hsl(206, 100%, 50%);--primary-contrast-text: hsl(216, 71%, 23%);--primary-button-contrast-text: hsl(0, 0%, 100%);--info-lighter: hsl(223, 98.4%, 97.1%);--info-light: hsl(224, 87.1%, 92%);--info-main: hsl(226, 70%, 55.5%);--info-main-8-p: hsla(226, 70%, 55.5%, .08);--info-main-50-p: hsla(226, 70%, 55.5%, .5);--info-dark: hsl(226, 58.6%, 51.3%);--info-darker: hsl(226, 55%, 45%);--info-outlined-border: hsl(226, 70%, 55.5%);--info-contrast-text: hsl(226, 50%, 24%);--info-button-contrast-text: hsl(0, 0%, 100%);--success-lighter: hsl(139, 55.2%, 94.5%);--success-light: hsl(141, 43.7%, 86%);--success-main: hsl(151, 55%, 41.5%);--success-main-8-p: hsla(151, 55%, 41.5%, .08);--success-main-50-p: hsla(151, 55%, 41.5%, .5);--success-dark: hsl(152, 57.5%, 37.6%);--success-darker: hsl(153, 67%, 28.5%);--success-outlined-border: hsl(151, 55%, 41.5%);--success-contrast-text: hsl(155, 40%, 16.5%);--success-button-contrast-text: hsl(0, 0%, 100%);--warning-lighter: hsl(45, 100%, 90.8%);--warning-light: hsl(40, 100%, 81.5%);--warning-main: hsl(42, 100%, 62%);--warning-main-8-p: hsla(42, 100%, 62%, .08);--warning-main-50-p: hsla(42, 100%, 62%, .5);--warning-dark: hsl(42, 100%, 55%);--warning-darker: hsl(25, 50%, 38%);--warning-outlined-border: hsl(42, 100%, 62%);--warning-contrast-text: hsl(25, 40%, 22%);--warning-button-contrast-text: hsl(24, 40%, 22%);--error-lighter: hsl(0, 100%, 96.8%);--error-light: hsl(0, 90.2%, 91.9%);--error-main: hsl(358, 75%, 59%);--error-main-8-p: hsla(358, 75%, 59%, .08);--error-main-50-p: hsla(358, 75%, 59%, .5);--error-dark: hsl(358, 67.4%, 54.6%);--error-darker: hsl(358, 65%, 47%);--error-outlined-border: hsl(358, 75%, 59%);--error-contrast-text: hsl(350, 63%, 24%);--error-button-contrast-text: hsl(0, 0%, 100%);--aba: #FFC134;--abb: #4F4FF5}:host{margin:0;padding:0;display:inline-block}:host button.fu-default,:host button.fu-primary,:host button.fu-danger,:host button.fu-info,:host button.fu-success,:host button.fu-warning{padding:var(--spacing-50, 4px);gap:0}:host button.fu-default .fu-button-icon,:host button.fu-primary .fu-button-icon,:host button.fu-danger .fu-button-icon,:host button.fu-info .fu-button-icon,:host button.fu-success .fu-button-icon,:host button.fu-warning .fu-button-icon{width:20px;height:20px}:host button.fu-default{color:var(--action-active, hsl(0, 0%, 50.3%));background-color:transparent}:host button.fu-default:hover{color:var(--default-contrast-text, hsl(0, 0%, 12.5%));background-color:var(--action-hover, hsla(0, 0%, 0%, .05))}:host button.fu-default.fu-outlined{padding:calc(var(--spacing-50, 4px) - 1px);color:var(--action-active, hsl(0, 0%, 50.3%));border-color:var(--action-outlined-border, hsl(0, 0%, 73%))}:host button.fu-default.fu-outlined:hover{color:var(--default-contrast-text, hsl(0, 0%, 12.5%));border-color:var(--action-active, hsl(0, 0%, 50.3%));background-color:var(--action-hover, hsla(0, 0%, 0%, .05))}:host button.fu-default.fu-outlined:disabled{border-color:var(--action-disabled, hsl(0, 0%, 87%))}:host button.fu-default:disabled{color:var(--action-disabled, hsl(0, 0%, 87%))}:host button.fu-default:disabled:hover{color:var(--action-disabled, hsl(0, 0%, 87%));background-color:transparent}:host button.fu-primary{color:var(--primary-main, hsl(206, 100%, 50%));background-color:transparent}:host button.fu-primary:hover{color:var(--primary-main, hsl(206, 100%, 50%));background-color:var(--primary-main-8-p, hsla(206, 100%, 50%, .08))}:host button.fu-primary.fu-outlined{padding:calc(var(--spacing-50, 4px) - 1px);color:var(--primary-main, hsl(206, 100%, 50%));border-color:var(--primary-main, hsl(206, 100%, 50%))}:host button.fu-primary.fu-outlined:hover{color:var(--primary-main, hsl(206, 100%, 50%));border-color:var(--primary-main, hsl(206, 100%, 50%));background-color:var(--primary-main-8-p, hsla(206, 100%, 50%, .08))}:host button.fu-primary.fu-outlined:disabled{color:var(--action-disabled, hsl(0, 0%, 87%));border-color:var(--action-disabled, hsl(0, 0%, 87%))}:host button.fu-danger{color:var(--error-main, hsl(358, 75%, 59%));background-color:transparent}:host button.fu-danger:hover{color:var(--error-main, hsl(358, 75%, 59%));background-color:var(--error-main-8-p, hsla(358, 75%, 59%, .08))}:host button.fu-danger.fu-outlined{padding:calc(var(--spacing-50, 4px) - 1px);color:var(--error-main, hsl(358, 75%, 59%));border-color:var(--error-main, hsl(358, 75%, 59%))}:host button.fu-danger.fu-outlined:hover{color:var(--error-main, hsl(358, 75%, 59%));border-color:var(--error-main, hsl(358, 75%, 59%));background-color:var(--error-main-8-p, hsla(358, 75%, 59%, .08))}:host button.fu-danger.fu-outlined:disabled{color:var(--action-disabled, hsl(0, 0%, 87%));border-color:var(--action-disabled, hsl(0, 0%, 87%))}:host button.fu-info{color:var(--info-main, hsl(226, 70%, 55.5%));background-color:transparent}:host button.fu-info:hover{color:var(--info-main, hsl(226, 70%, 55.5%));background-color:var(--info-main-8-p, hsla(226, 70%, 55.5%, .08))}:host button.fu-info.fu-outlined{padding:calc(var(--spacing-50, 4px) - 1px);color:var(--info-main, hsl(226, 70%, 55.5%));border-color:var(--info-main, hsl(226, 70%, 55.5%))}:host button.fu-info.fu-outlined:hover{color:var(--info-main, hsl(226, 70%, 55.5%));border-color:var(--info-main, hsl(226, 70%, 55.5%));background-color:var(--info-main-8-p, hsla(226, 70%, 55.5%, .08))}:host button.fu-info.fu-outlined:disabled{color:var(--action-disabled, hsl(0, 0%, 87%));border-color:var(--action-disabled, hsl(0, 0%, 87%))}:host button.fu-success{color:var(--success-main, hsl(151, 55%, 41.5%));background-color:transparent}:host button.fu-success:hover{color:var(--success-main, hsl(151, 55%, 41.5%));background-color:var(--success-main-8-p, hsla(151, 55%, 41.5%, .08))}:host button.fu-success.fu-outlined{padding:calc(var(--spacing-50, 4px) - 1px);color:var(--success-main, hsl(151, 55%, 41.5%));border-color:var(--success-main, hsl(151, 55%, 41.5%))}:host button.fu-success.fu-outlined:hover{color:var(--success-main, hsl(151, 55%, 41.5%));border-color:var(--success-main, hsl(151, 55%, 41.5%));background-color:var(--success-main-8-p, hsla(151, 55%, 41.5%, .08))}:host button.fu-success.fu-outlined:disabled{color:var(--action-disabled, hsl(0, 0%, 87%));border-color:var(--action-disabled, hsl(0, 0%, 87%))}:host button.fu-warning{color:var(--warning-main, hsl(42, 100%, 62%));background-color:transparent}:host button.fu-warning:hover{color:var(--warning-main, hsl(42, 100%, 62%));background-color:var(--warning-main-8-p, hsla(42, 100%, 62%, .08))}:host button.fu-warning.fu-outlined{padding:calc(var(--spacing-50, 4px) - 1px);color:var(--warning-main, hsl(42, 100%, 62%));border-color:var(--warning-main, hsl(42, 100%, 62%))}:host button.fu-warning.fu-outlined:hover{color:var(--warning-main, hsl(42, 100%, 62%));border-color:var(--warning-main, hsl(42, 100%, 62%));background-color:var(--warning-main-8-p, hsla(42, 100%, 62%, .08))}:host button.fu-warning.fu-outlined:disabled{color:var(--action-disabled, hsl(0, 0%, 87%));border-color:var(--action-disabled, hsl(0, 0%, 87%))}:host button.fu-extraSmall{padding:var(--spacing-25, 2px)}:host button.fu-extraSmall.fu-outlined{padding:calc(var(--spacing-25, 2px) - 1px)}:host button.fu-extraSmall .fu-button-icon{width:16px;height:16px}:host button.fu-small{padding:var(--spacing-25, 2px)}:host button.fu-small.fu-outlined{padding:calc(var(--spacing-25, 2px) - 1px)}:host button.fu-large{padding:var(--spacing-50, 4px)}:host button.fu-large.fu-outlined{padding:calc(var(--spacing-50, 4px) - 1px)}:host button.fu-extraLarge{padding:var(--spacing-100, 8px)}:host button.fu-extraLarge.fu-outlined{padding:calc(var(--spacing-100, 8px) - 1px)}:host button.fu-large .fu-button-icon,:host button.fu-extraLarge .fu-button-icon{width:24px;height:24px}\n"] }]
    }], null, { iconName: [{
            type: Input
        }], color: [{
            type: Input
        }], variant: [{
            type: Input
        }], size: [{
            type: Input
        }] }); })();
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassDebugInfo(IconButtonComponent, { className: "IconButtonComponent", filePath: "icon-button/icon-button.component.ts", lineNumber: 18 }); })();

/**
 * Generated bundle index. Do not edit.
 */

export { ButtonComponent, IconButtonComponent };
//# sourceMappingURL=ironsource-fusion-ui-components-button-v4.mjs.map
