import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy, Input, EventEmitter, HostBinding, Output, ContentChildren } from '@angular/core';
import { CommonModule } from '@angular/common';
import { Subject, fromEvent } from 'rxjs';
import { takeUntil } from 'rxjs/operators';
import { GenericPipe } from '@ironsource/fusion-ui/pipes/generic';

const _c0$1 = ["*"];
const ATTRIBUTE_SELECTED = 'tab-selected';
const ATTRIBUTE_DISABLED = 'tab-disabled';
class TabV4Component {
    set selected(value) {
        this.toggleSelected(value);
    }
    set disabled(value) {
        this.toggleDisabled(value);
    }
    // need it for using @ContentChildren in tabs component
    get nativeElement() {
        return this._element.nativeElement;
    }
    get selected() {
        return this.nativeElement.hasAttribute(ATTRIBUTE_SELECTED);
    }
    constructor(_element, _renderer) {
        this._element = _element;
        this._renderer = _renderer;
    }
    ngAfterViewInit() {
        const tabsElement = this._element.nativeElement.closest('fusion-tabs');
        if (tabsElement && (tabsElement.classList.contains('fu-size-xl') || tabsElement.classList.contains('fu-size-lg'))) {
            this.setIconAloneClass();
        }
    }
    setIconAloneClass() {
        const element = this._element.nativeElement.querySelector('.fu-tab-content');
        if (element.querySelector('.fu-tab-icon') && !element.textContent.trim().length) {
            this._renderer.addClass(element, 'fu-icon-alone');
        }
    }
    toggleSelected(isSelected) {
        const elementNative = this._element.nativeElement;
        if (isSelected) {
            this._renderer.setAttribute(elementNative, ATTRIBUTE_SELECTED, '');
        }
        else {
            this._renderer.removeAttribute(elementNative, ATTRIBUTE_SELECTED);
        }
    }
    toggleDisabled(isDisabled) {
        const elementNative = this._element.nativeElement;
        if (isDisabled) {
            this._renderer.setAttribute(elementNative, ATTRIBUTE_DISABLED, '');
        }
        else {
            this._renderer.removeAttribute(elementNative, ATTRIBUTE_DISABLED);
        }
    }
    static { this.ɵfac = function TabV4Component_Factory(t) { return new (t || TabV4Component)(i0.ɵɵdirectiveInject(i0.ElementRef), i0.ɵɵdirectiveInject(i0.Renderer2)); }; }
    static { this.ɵcmp = /*@__PURE__*/ i0.ɵɵdefineComponent({ type: TabV4Component, selectors: [["fusion-tab"]], hostAttrs: [1, "fusion-v4"], inputs: { selected: "selected", testId: "testId", disabled: "disabled" }, standalone: true, features: [i0.ɵɵStandaloneFeature], ngContentSelectors: _c0$1, decls: 2, vars: 1, consts: [[1, "fu-tab-content"]], template: function TabV4Component_Template(rf, ctx) { if (rf & 1) {
            i0.ɵɵprojectionDef();
            i0.ɵɵelementStart(0, "div", 0);
            i0.ɵɵprojection(1);
            i0.ɵɵelementEnd();
        } if (rf & 2) {
            i0.ɵɵattribute("data-testid", ctx.testId);
        } }, dependencies: [CommonModule], styles: ["@import\"https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600;700&display=swap\";.fusion-v4[_ngcontent-%COMP%]{--background-default: #FFFFFF;--background-paper: hsl(0, 0%, 99%);--background-model-elevation: #FFFFFF;--background-backdrop: hsla(0, 0%, 0%, .11);--background-paper-elevation-0: hsl(0, 0%, 97.5%);--background-paper-elevation-1: hsl(0, 0%, 94.6%);--background-paper-elevation-2: hsl(0, 0%, 92%);--background-paper-elevation-3: hsl(0, 0%, 89.5%);--background-paper-elevation-4: hsl(0, 0%, 86.8%);--background-paper-elevation-5: hsl(0, 0%, 83%);--background-paper-elevation-6: hsl(0, 0%, 73.2%);--background-paper-elevation-7: hsl(0, 0%, 55.2%);--background-paper-elevation-8: hsl(0, 0%, 50.3%);--background-paper-elevation-9: hsl(0, 0%, 39.3%);--action-primary: hsl(0, 0%, 12.5%);--action-active: hsl(0, 0%, 50.3%);--action-hover: hsla(0, 0%, 0%, .05);--action-selected: hsl(0, 0%, 92%);--action-disabled: hsl(0, 0%, 87%);--action-disabled-background: hsl(0, 0%, 95%);--action-focus: hsl(0, 0%, 92%);--action-outlined-border: hsl(0, 0%, 73%);--default-light: hsl(0, 0%, 89.5%);--default-main: hsl(0, 0%, 94.51%);--default-dark: hsl(0, 0%, 92%);--default-outlined-border: hsl(0, 0%, 73.2%);--default-contrast-text: hsl(0, 0%, 12.5%);--default-button-contrast-text: hsl(0, 0%, 0%);--common-white: #FFFFFF;--common-black: #000000;--common-inverse-white: #FFFFFF;--common-inverse-black: #000000;--common-divider: hsl(0, 0%, 86.8%);--common-divider-elevation-0: hsl(0, 0%, 89%);--text-primary: hsl(0, 0%, 12.5%);--text-secondary: hsl(0, 0%, 39.3%);--text-disabled: hsl(0, 0%, 73.33%);--primary-lighter: hsl(209, 100%, 96.5%);--primary-light: hsl(209, 95%, 90.1%);--primary-main: hsl(206, 100%, 50%);--primary-main-8-p: hsla(206, 100%, 50%, .08);--primary-main-50-p: hsla(206, 100%, 50%, .5);--primary-dark: hsl(208, 93.5%, 47.4%);--primary-darker: hsl(211, 90%, 42%);--primary-outlined-border: hsl(206, 100%, 50%);--primary-contrast-text: hsl(216, 71%, 23%);--primary-button-contrast-text: hsl(0, 0%, 100%);--info-lighter: hsl(223, 98.4%, 97.1%);--info-light: hsl(224, 87.1%, 92%);--info-main: hsl(226, 70%, 55.5%);--info-main-8-p: hsla(226, 70%, 55.5%, .08);--info-main-50-p: hsla(226, 70%, 55.5%, .5);--info-dark: hsl(226, 58.6%, 51.3%);--info-darker: hsl(226, 55%, 45%);--info-outlined-border: hsl(226, 70%, 55.5%);--info-contrast-text: hsl(226, 50%, 24%);--info-button-contrast-text: hsl(0, 0%, 100%);--success-lighter: hsl(139, 55.2%, 94.5%);--success-light: hsl(141, 43.7%, 86%);--success-main: hsl(151, 55%, 41.5%);--success-main-8-p: hsla(151, 55%, 41.5%, .08);--success-main-50-p: hsla(151, 55%, 41.5%, .5);--success-dark: hsl(152, 57.5%, 37.6%);--success-darker: hsl(153, 67%, 28.5%);--success-outlined-border: hsl(151, 55%, 41.5%);--success-contrast-text: hsl(155, 40%, 16.5%);--success-button-contrast-text: hsl(0, 0%, 100%);--warning-lighter: hsl(45, 100%, 90.8%);--warning-light: hsl(40, 100%, 81.5%);--warning-main: hsl(42, 100%, 62%);--warning-main-8-p: hsla(42, 100%, 62%, .08);--warning-main-50-p: hsla(42, 100%, 62%, .5);--warning-dark: hsl(42, 100%, 55%);--warning-darker: hsl(25, 50%, 38%);--warning-outlined-border: hsl(42, 100%, 62%);--warning-contrast-text: hsl(25, 40%, 22%);--warning-button-contrast-text: hsl(24, 40%, 22%);--error-lighter: hsl(0, 100%, 96.8%);--error-light: hsl(0, 90.2%, 91.9%);--error-main: hsl(358, 75%, 59%);--error-main-8-p: hsla(358, 75%, 59%, .08);--error-main-50-p: hsla(358, 75%, 59%, .5);--error-dark: hsl(358, 67.4%, 54.6%);--error-darker: hsl(358, 65%, 47%);--error-outlined-border: hsl(358, 75%, 59%);--error-contrast-text: hsl(350, 63%, 24%);--error-button-contrast-text: hsl(0, 0%, 100%);--aba: #FFC134;--abb: #4F4FF5}.fusion-v4[_ngcontent-%COMP%]{--spacing-tockenset: 0px;--spacing-25: 2px;--spacing-50: 4px;--spacing-75: 6px;--spacing-100: 8px;--spacing-125: 10px;--spacing-150: 12px;--spacing-200: 16px;--spacing-250: 20px;--spacing-300: 24px;--spacing-400: 32px;--spacing-500: 40px;--spacing-600: 48px;--spacing-700: 56px;--spacing-800: 64px;--spacing-900: 72px;--spacing-1000: 80px}.fusion-v4[_ngcontent-%COMP%]{--border-radius-xs: 2px;--border-radius-sm: 4px;--border-radius-md: 6px;--border-radius-lg: 8px;--border-radius-xl: 16px;--border-radius-full: 100px}.font-v4-bold[_ngcontent-%COMP%], [tab-selected][_nghost-%COMP%]   .fu-tab-content[_ngcontent-%COMP%], .font-v4-tab-label-2[_ngcontent-%COMP%], .font-v4-chart-2[_ngcontent-%COMP%], .font-v4-chart-1[_ngcontent-%COMP%]{font-family:Inter,sans-serif;font-weight:700;-webkit-font-smoothing:antialiased}.font-v4-semibold[_ngcontent-%COMP%], .font-v4-chip-label[_ngcontent-%COMP%], .font-v4-table-label[_ngcontent-%COMP%], .font-v4-button[_ngcontent-%COMP%], .font-v4-heading-6[_ngcontent-%COMP%], .font-v4-heading-5[_ngcontent-%COMP%], .font-v4-heading-4[_ngcontent-%COMP%], .font-v4-heading-3[_ngcontent-%COMP%], .font-v4-heading-2[_ngcontent-%COMP%], .font-v4-heading-1[_ngcontent-%COMP%], .font-v4-title[_ngcontent-%COMP%]{font-family:Inter,sans-serif;font-weight:600;-webkit-font-smoothing:antialiased}.font-v4-medium[_ngcontent-%COMP%], [_nghost-%COMP%]   .fu-tab-content[_ngcontent-%COMP%], .font-v4-tab-label-1[_ngcontent-%COMP%], .font-v4-input-label[_ngcontent-%COMP%], .font-v4-overline[_ngcontent-%COMP%], .font-v4-subtitle-2[_ngcontent-%COMP%], .font-v4-subtitle-1[_ngcontent-%COMP%]{font-family:Inter,sans-serif;font-weight:500;-webkit-font-smoothing:antialiased}.font-v4-regular[_ngcontent-%COMP%], .font-v4-caption[_ngcontent-%COMP%], .font-v4-body-2[_ngcontent-%COMP%], .font-v4-body-1[_ngcontent-%COMP%]{font-family:Inter,sans-serif;font-weight:400;-webkit-font-smoothing:antialiased}.font-v4-title[_ngcontent-%COMP%]{font-size:2.5rem;line-height:3rem;letter-spacing:-.055rem}.font-v4-heading-1[_ngcontent-%COMP%]{font-size:1.5rem;line-height:1.75rem;letter-spacing:-.0285rem}.font-v4-heading-2[_ngcontent-%COMP%]{font-size:1.125rem;line-height:1.75rem;letter-spacing:-.01575rem}.font-v4-heading-3[_ngcontent-%COMP%]{font-size:1rem;line-height:1.5rem;letter-spacing:-.011rem}.font-v4-heading-4[_ngcontent-%COMP%]{font-size:.875rem;line-height:1rem;letter-spacing:unset}.font-v4-heading-5[_ngcontent-%COMP%]{font-size:.8125rem;line-height:16px;letter-spacing:unset}.font-v4-heading-6[_ngcontent-%COMP%]{font-size:.75rem;line-height:.75rem;letter-spacing:0}.font-v4-body-1[_ngcontent-%COMP%]{font-size:.875rem;line-height:1.25rem;letter-spacing:-.00525rem}.font-v4-body-2[_ngcontent-%COMP%]{font-size:.8125rem;line-height:1.25rem;letter-spacing:-.00244rem}.font-v4-subtitle-1[_ngcontent-%COMP%]{font-size:.875rem;line-height:1.25rem;letter-spacing:-.00525rem}.font-v4-subtitle-2[_ngcontent-%COMP%]{font-size:.8125rem;line-height:1.25rem;letter-spacing:-.00244rem}.font-v4-chart-1[_ngcontent-%COMP%]{font-size:1.5rem;line-height:1.5rem;letter-spacing:-.015rem}.font-v4-chart-2[_ngcontent-%COMP%]{font-size:1.25rem;line-height:1.25rem;letter-spacing:-.0125rem}.font-v4-button[_ngcontent-%COMP%]{font-size:.875rem;line-height:1.25rem;letter-spacing:.00875rem}.font-v4-overline[_ngcontent-%COMP%]{font-size:.75rem;line-height:1rem;letter-spacing:.045rem;text-transform:uppercase}.font-v4-caption[_ngcontent-%COMP%]{font-size:.75rem;line-height:1rem}.font-v4-table-label[_ngcontent-%COMP%]{font-size:.8125rem;line-height:1.25rem;letter-spacing:.00813rem}.font-v4-input-label[_ngcontent-%COMP%]{font-size:.8125rem;line-height:1rem;letter-spacing:.00813rem}[_nghost-%COMP%]   .fu-tab-content[_ngcontent-%COMP%], .font-v4-tab-label-1[_ngcontent-%COMP%]{font-size:.875rem;line-height:1rem}[tab-selected][_nghost-%COMP%]   .fu-tab-content[_ngcontent-%COMP%], .font-v4-tab-label-2[_ngcontent-%COMP%]{font-size:.875rem;line-height:1rem}.font-v4-chip-label[_ngcontent-%COMP%]{font-size:.75rem;line-height:1rem;letter-spacing:normal}[_nghost-%COMP%]{margin:0;padding:0;-webkit-user-select:none;user-select:none}[_nghost-%COMP%]   .fu-tab-content[_ngcontent-%COMP%]{box-sizing:border-box;min-height:var(--spacing-600, 48px);width:-moz-fit-content;width:fit-content;display:flex;flex-direction:row;justify-content:center;align-items:center;gap:var(--spacing-100, 8px);padding:var(--spacing-200, 16px) var(--spacing-300, 24px);color:var(--action-active, hsl(0, 0%, 50.3%))}[_nghost-%COMP%]   .fu-tab-content[_ngcontent-%COMP%]:hover{cursor:pointer;color:var(--text-primary, hsl(0, 0%, 12.5%))}[tab-disabled][_nghost-%COMP%], [tab-selected][_nghost-%COMP%]{pointer-events:none;touch-callout:none}[tab-disabled][_nghost-%COMP%]   .fu-tab-content[_ngcontent-%COMP%]{color:var(--action-disabled, hsl(0, 0%, 87%));cursor:default}[tab-selected][_nghost-%COMP%]   .fu-tab-content[_ngcontent-%COMP%]{color:var(--text-primary, hsl(0, 0%, 12.5%));border-bottom:2px solid var(--primary-main, hsl(206, 100%, 50%));cursor:default;padding-bottom:calc(var(--spacing-200, 16px) - 2px)}.fu-tabs-page[_nghost-%COMP%], .fu-tabs-page   [_nghost-%COMP%]{margin-bottom:-1px}.fu-tabs-page[_nghost-%COMP%]   .fu-tab-content[_ngcontent-%COMP%], .fu-tabs-page   [_nghost-%COMP%]   .fu-tab-content[_ngcontent-%COMP%]{padding:var(--spacing-200, 16px) 0}.fu-tabs-page[tab-selected][_nghost-%COMP%]   .fu-tab-content[_ngcontent-%COMP%], .fu-tabs-page   [tab-selected][_nghost-%COMP%]   .fu-tab-content[_ngcontent-%COMP%]{padding-bottom:calc(var(--spacing-200, 16px) - 2px)}"], changeDetection: 0 }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(TabV4Component, [{
        type: Component,
        args: [{ selector: 'fusion-tab', standalone: true, imports: [CommonModule, GenericPipe], host: { class: 'fusion-v4' }, template: '<div class="fu-tab-content" [attr.data-testid]="testId"><ng-content></ng-content></div>', changeDetection: ChangeDetectionStrategy.OnPush, styles: ["@import\"https://fonts.googleapis.com/css2?family=Inter:wght@400;500;600;700&display=swap\";.fusion-v4{--background-default: #FFFFFF;--background-paper: hsl(0, 0%, 99%);--background-model-elevation: #FFFFFF;--background-backdrop: hsla(0, 0%, 0%, .11);--background-paper-elevation-0: hsl(0, 0%, 97.5%);--background-paper-elevation-1: hsl(0, 0%, 94.6%);--background-paper-elevation-2: hsl(0, 0%, 92%);--background-paper-elevation-3: hsl(0, 0%, 89.5%);--background-paper-elevation-4: hsl(0, 0%, 86.8%);--background-paper-elevation-5: hsl(0, 0%, 83%);--background-paper-elevation-6: hsl(0, 0%, 73.2%);--background-paper-elevation-7: hsl(0, 0%, 55.2%);--background-paper-elevation-8: hsl(0, 0%, 50.3%);--background-paper-elevation-9: hsl(0, 0%, 39.3%);--action-primary: hsl(0, 0%, 12.5%);--action-active: hsl(0, 0%, 50.3%);--action-hover: hsla(0, 0%, 0%, .05);--action-selected: hsl(0, 0%, 92%);--action-disabled: hsl(0, 0%, 87%);--action-disabled-background: hsl(0, 0%, 95%);--action-focus: hsl(0, 0%, 92%);--action-outlined-border: hsl(0, 0%, 73%);--default-light: hsl(0, 0%, 89.5%);--default-main: hsl(0, 0%, 94.51%);--default-dark: hsl(0, 0%, 92%);--default-outlined-border: hsl(0, 0%, 73.2%);--default-contrast-text: hsl(0, 0%, 12.5%);--default-button-contrast-text: hsl(0, 0%, 0%);--common-white: #FFFFFF;--common-black: #000000;--common-inverse-white: #FFFFFF;--common-inverse-black: #000000;--common-divider: hsl(0, 0%, 86.8%);--common-divider-elevation-0: hsl(0, 0%, 89%);--text-primary: hsl(0, 0%, 12.5%);--text-secondary: hsl(0, 0%, 39.3%);--text-disabled: hsl(0, 0%, 73.33%);--primary-lighter: hsl(209, 100%, 96.5%);--primary-light: hsl(209, 95%, 90.1%);--primary-main: hsl(206, 100%, 50%);--primary-main-8-p: hsla(206, 100%, 50%, .08);--primary-main-50-p: hsla(206, 100%, 50%, .5);--primary-dark: hsl(208, 93.5%, 47.4%);--primary-darker: hsl(211, 90%, 42%);--primary-outlined-border: hsl(206, 100%, 50%);--primary-contrast-text: hsl(216, 71%, 23%);--primary-button-contrast-text: hsl(0, 0%, 100%);--info-lighter: hsl(223, 98.4%, 97.1%);--info-light: hsl(224, 87.1%, 92%);--info-main: hsl(226, 70%, 55.5%);--info-main-8-p: hsla(226, 70%, 55.5%, .08);--info-main-50-p: hsla(226, 70%, 55.5%, .5);--info-dark: hsl(226, 58.6%, 51.3%);--info-darker: hsl(226, 55%, 45%);--info-outlined-border: hsl(226, 70%, 55.5%);--info-contrast-text: hsl(226, 50%, 24%);--info-button-contrast-text: hsl(0, 0%, 100%);--success-lighter: hsl(139, 55.2%, 94.5%);--success-light: hsl(141, 43.7%, 86%);--success-main: hsl(151, 55%, 41.5%);--success-main-8-p: hsla(151, 55%, 41.5%, .08);--success-main-50-p: hsla(151, 55%, 41.5%, .5);--success-dark: hsl(152, 57.5%, 37.6%);--success-darker: hsl(153, 67%, 28.5%);--success-outlined-border: hsl(151, 55%, 41.5%);--success-contrast-text: hsl(155, 40%, 16.5%);--success-button-contrast-text: hsl(0, 0%, 100%);--warning-lighter: hsl(45, 100%, 90.8%);--warning-light: hsl(40, 100%, 81.5%);--warning-main: hsl(42, 100%, 62%);--warning-main-8-p: hsla(42, 100%, 62%, .08);--warning-main-50-p: hsla(42, 100%, 62%, .5);--warning-dark: hsl(42, 100%, 55%);--warning-darker: hsl(25, 50%, 38%);--warning-outlined-border: hsl(42, 100%, 62%);--warning-contrast-text: hsl(25, 40%, 22%);--warning-button-contrast-text: hsl(24, 40%, 22%);--error-lighter: hsl(0, 100%, 96.8%);--error-light: hsl(0, 90.2%, 91.9%);--error-main: hsl(358, 75%, 59%);--error-main-8-p: hsla(358, 75%, 59%, .08);--error-main-50-p: hsla(358, 75%, 59%, .5);--error-dark: hsl(358, 67.4%, 54.6%);--error-darker: hsl(358, 65%, 47%);--error-outlined-border: hsl(358, 75%, 59%);--error-contrast-text: hsl(350, 63%, 24%);--error-button-contrast-text: hsl(0, 0%, 100%);--aba: #FFC134;--abb: #4F4FF5}.fusion-v4{--spacing-tockenset: 0px;--spacing-25: 2px;--spacing-50: 4px;--spacing-75: 6px;--spacing-100: 8px;--spacing-125: 10px;--spacing-150: 12px;--spacing-200: 16px;--spacing-250: 20px;--spacing-300: 24px;--spacing-400: 32px;--spacing-500: 40px;--spacing-600: 48px;--spacing-700: 56px;--spacing-800: 64px;--spacing-900: 72px;--spacing-1000: 80px}.fusion-v4{--border-radius-xs: 2px;--border-radius-sm: 4px;--border-radius-md: 6px;--border-radius-lg: 8px;--border-radius-xl: 16px;--border-radius-full: 100px}.font-v4-bold,:host[tab-selected] .fu-tab-content,.font-v4-tab-label-2,.font-v4-chart-2,.font-v4-chart-1{font-family:Inter,sans-serif;font-weight:700;-webkit-font-smoothing:antialiased}.font-v4-semibold,.font-v4-chip-label,.font-v4-table-label,.font-v4-button,.font-v4-heading-6,.font-v4-heading-5,.font-v4-heading-4,.font-v4-heading-3,.font-v4-heading-2,.font-v4-heading-1,.font-v4-title{font-family:Inter,sans-serif;font-weight:600;-webkit-font-smoothing:antialiased}.font-v4-medium,:host .fu-tab-content,.font-v4-tab-label-1,.font-v4-input-label,.font-v4-overline,.font-v4-subtitle-2,.font-v4-subtitle-1{font-family:Inter,sans-serif;font-weight:500;-webkit-font-smoothing:antialiased}.font-v4-regular,.font-v4-caption,.font-v4-body-2,.font-v4-body-1{font-family:Inter,sans-serif;font-weight:400;-webkit-font-smoothing:antialiased}.font-v4-title{font-size:2.5rem;line-height:3rem;letter-spacing:-.055rem}.font-v4-heading-1{font-size:1.5rem;line-height:1.75rem;letter-spacing:-.0285rem}.font-v4-heading-2{font-size:1.125rem;line-height:1.75rem;letter-spacing:-.01575rem}.font-v4-heading-3{font-size:1rem;line-height:1.5rem;letter-spacing:-.011rem}.font-v4-heading-4{font-size:.875rem;line-height:1rem;letter-spacing:unset}.font-v4-heading-5{font-size:.8125rem;line-height:16px;letter-spacing:unset}.font-v4-heading-6{font-size:.75rem;line-height:.75rem;letter-spacing:0}.font-v4-body-1{font-size:.875rem;line-height:1.25rem;letter-spacing:-.00525rem}.font-v4-body-2{font-size:.8125rem;line-height:1.25rem;letter-spacing:-.00244rem}.font-v4-subtitle-1{font-size:.875rem;line-height:1.25rem;letter-spacing:-.00525rem}.font-v4-subtitle-2{font-size:.8125rem;line-height:1.25rem;letter-spacing:-.00244rem}.font-v4-chart-1{font-size:1.5rem;line-height:1.5rem;letter-spacing:-.015rem}.font-v4-chart-2{font-size:1.25rem;line-height:1.25rem;letter-spacing:-.0125rem}.font-v4-button{font-size:.875rem;line-height:1.25rem;letter-spacing:.00875rem}.font-v4-overline{font-size:.75rem;line-height:1rem;letter-spacing:.045rem;text-transform:uppercase}.font-v4-caption{font-size:.75rem;line-height:1rem}.font-v4-table-label{font-size:.8125rem;line-height:1.25rem;letter-spacing:.00813rem}.font-v4-input-label{font-size:.8125rem;line-height:1rem;letter-spacing:.00813rem}:host .fu-tab-content,.font-v4-tab-label-1{font-size:.875rem;line-height:1rem}:host[tab-selected] .fu-tab-content,.font-v4-tab-label-2{font-size:.875rem;line-height:1rem}.font-v4-chip-label{font-size:.75rem;line-height:1rem;letter-spacing:normal}:host{margin:0;padding:0;-webkit-user-select:none;user-select:none}:host .fu-tab-content{box-sizing:border-box;min-height:var(--spacing-600, 48px);width:-moz-fit-content;width:fit-content;display:flex;flex-direction:row;justify-content:center;align-items:center;gap:var(--spacing-100, 8px);padding:var(--spacing-200, 16px) var(--spacing-300, 24px);color:var(--action-active, hsl(0, 0%, 50.3%))}:host .fu-tab-content:hover{cursor:pointer;color:var(--text-primary, hsl(0, 0%, 12.5%))}:host[tab-disabled],:host[tab-selected]{pointer-events:none;touch-callout:none}:host[tab-disabled] .fu-tab-content{color:var(--action-disabled, hsl(0, 0%, 87%));cursor:default}:host[tab-selected] .fu-tab-content{color:var(--text-primary, hsl(0, 0%, 12.5%));border-bottom:2px solid var(--primary-main, hsl(206, 100%, 50%));cursor:default;padding-bottom:calc(var(--spacing-200, 16px) - 2px)}:host-context(.fu-tabs-page){margin-bottom:-1px}:host-context(.fu-tabs-page) .fu-tab-content{padding:var(--spacing-200, 16px) 0}:host-context(.fu-tabs-page)[tab-selected] .fu-tab-content{padding-bottom:calc(var(--spacing-200, 16px) - 2px)}\n"] }]
    }], () => [{ type: i0.ElementRef }, { type: i0.Renderer2 }], { selected: [{
            type: Input
        }], testId: [{
            type: Input
        }], disabled: [{
            type: Input
        }] }); })();
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassDebugInfo(TabV4Component, { className: "TabV4Component", filePath: "tab/tab-v4.component.ts", lineNumber: 17 }); })();

const _c0 = ["*"];
class TabsV4Component {
    get isPage() {
        return this.variant === 'page';
    }
    constructor(_element, _renderer) {
        this._element = _element;
        this._renderer = _renderer;
        this.variant = 'card';
        this.selectedChange = new EventEmitter();
        /** @internal */
        this.onDestroy$ = new Subject();
    }
    ngOnInit() {
        fromEvent(this._element.nativeElement, 'click').pipe(takeUntil(this.onDestroy$)).subscribe(this.onClick.bind(this));
    }
    ngOnDestroy() {
        this.onDestroy$.next();
        this.onDestroy$.complete();
    }
    onClick(event) {
        const clickedTabElement = event.target.closest('fusion-tab');
        if (clickedTabElement) {
            const selectedTabIndex = this.setSelectedAndGetIndex(clickedTabElement);
            this.selectedChange.emit({ index: selectedTabIndex, tabElement: clickedTabElement });
        }
    }
    setSelectedAndGetIndex(tabElementToSelect) {
        let selectedTabIndex;
        this.tabList.forEach((tab, idx) => {
            if (tab.selected) {
                tab.selected = false;
            }
            else if (tab.nativeElement === tabElementToSelect) {
                tab.selected = true;
                selectedTabIndex = idx;
            }
        });
        return selectedTabIndex;
    }
    static { this.ɵfac = function TabsV4Component_Factory(t) { return new (t || TabsV4Component)(i0.ɵɵdirectiveInject(i0.ElementRef), i0.ɵɵdirectiveInject(i0.Renderer2)); }; }
    static { this.ɵcmp = /*@__PURE__*/ i0.ɵɵdefineComponent({ type: TabsV4Component, selectors: [["fusion-tabs"]], contentQueries: function TabsV4Component_ContentQueries(rf, ctx, dirIndex) { if (rf & 1) {
            i0.ɵɵcontentQuery(dirIndex, TabV4Component, 4);
        } if (rf & 2) {
            let _t;
            i0.ɵɵqueryRefresh(_t = i0.ɵɵloadQuery()) && (ctx.tabList = _t);
        } }, hostAttrs: [1, "fusion-v4"], hostVars: 2, hostBindings: function TabsV4Component_HostBindings(rf, ctx) { if (rf & 2) {
            i0.ɵɵclassProp("fu-tabs-page", ctx.isPage);
        } }, inputs: { variant: "variant", testId: "testId" }, outputs: { selectedChange: "selectedChange" }, standalone: true, features: [i0.ɵɵStandaloneFeature], ngContentSelectors: _c0, decls: 1, vars: 0, template: function TabsV4Component_Template(rf, ctx) { if (rf & 1) {
            i0.ɵɵprojectionDef();
            i0.ɵɵprojection(0);
        } }, dependencies: [CommonModule], styles: [".fusion-v4[_ngcontent-%COMP%]{--background-default: #FFFFFF;--background-paper: hsl(0, 0%, 99%);--background-model-elevation: #FFFFFF;--background-backdrop: hsla(0, 0%, 0%, .11);--background-paper-elevation-0: hsl(0, 0%, 97.5%);--background-paper-elevation-1: hsl(0, 0%, 94.6%);--background-paper-elevation-2: hsl(0, 0%, 92%);--background-paper-elevation-3: hsl(0, 0%, 89.5%);--background-paper-elevation-4: hsl(0, 0%, 86.8%);--background-paper-elevation-5: hsl(0, 0%, 83%);--background-paper-elevation-6: hsl(0, 0%, 73.2%);--background-paper-elevation-7: hsl(0, 0%, 55.2%);--background-paper-elevation-8: hsl(0, 0%, 50.3%);--background-paper-elevation-9: hsl(0, 0%, 39.3%);--action-primary: hsl(0, 0%, 12.5%);--action-active: hsl(0, 0%, 50.3%);--action-hover: hsla(0, 0%, 0%, .05);--action-selected: hsl(0, 0%, 92%);--action-disabled: hsl(0, 0%, 87%);--action-disabled-background: hsl(0, 0%, 95%);--action-focus: hsl(0, 0%, 92%);--action-outlined-border: hsl(0, 0%, 73%);--default-light: hsl(0, 0%, 89.5%);--default-main: hsl(0, 0%, 94.51%);--default-dark: hsl(0, 0%, 92%);--default-outlined-border: hsl(0, 0%, 73.2%);--default-contrast-text: hsl(0, 0%, 12.5%);--default-button-contrast-text: hsl(0, 0%, 0%);--common-white: #FFFFFF;--common-black: #000000;--common-inverse-white: #FFFFFF;--common-inverse-black: #000000;--common-divider: hsl(0, 0%, 86.8%);--common-divider-elevation-0: hsl(0, 0%, 89%);--text-primary: hsl(0, 0%, 12.5%);--text-secondary: hsl(0, 0%, 39.3%);--text-disabled: hsl(0, 0%, 73.33%);--primary-lighter: hsl(209, 100%, 96.5%);--primary-light: hsl(209, 95%, 90.1%);--primary-main: hsl(206, 100%, 50%);--primary-main-8-p: hsla(206, 100%, 50%, .08);--primary-main-50-p: hsla(206, 100%, 50%, .5);--primary-dark: hsl(208, 93.5%, 47.4%);--primary-darker: hsl(211, 90%, 42%);--primary-outlined-border: hsl(206, 100%, 50%);--primary-contrast-text: hsl(216, 71%, 23%);--primary-button-contrast-text: hsl(0, 0%, 100%);--info-lighter: hsl(223, 98.4%, 97.1%);--info-light: hsl(224, 87.1%, 92%);--info-main: hsl(226, 70%, 55.5%);--info-main-8-p: hsla(226, 70%, 55.5%, .08);--info-main-50-p: hsla(226, 70%, 55.5%, .5);--info-dark: hsl(226, 58.6%, 51.3%);--info-darker: hsl(226, 55%, 45%);--info-outlined-border: hsl(226, 70%, 55.5%);--info-contrast-text: hsl(226, 50%, 24%);--info-button-contrast-text: hsl(0, 0%, 100%);--success-lighter: hsl(139, 55.2%, 94.5%);--success-light: hsl(141, 43.7%, 86%);--success-main: hsl(151, 55%, 41.5%);--success-main-8-p: hsla(151, 55%, 41.5%, .08);--success-main-50-p: hsla(151, 55%, 41.5%, .5);--success-dark: hsl(152, 57.5%, 37.6%);--success-darker: hsl(153, 67%, 28.5%);--success-outlined-border: hsl(151, 55%, 41.5%);--success-contrast-text: hsl(155, 40%, 16.5%);--success-button-contrast-text: hsl(0, 0%, 100%);--warning-lighter: hsl(45, 100%, 90.8%);--warning-light: hsl(40, 100%, 81.5%);--warning-main: hsl(42, 100%, 62%);--warning-main-8-p: hsla(42, 100%, 62%, .08);--warning-main-50-p: hsla(42, 100%, 62%, .5);--warning-dark: hsl(42, 100%, 55%);--warning-darker: hsl(25, 50%, 38%);--warning-outlined-border: hsl(42, 100%, 62%);--warning-contrast-text: hsl(25, 40%, 22%);--warning-button-contrast-text: hsl(24, 40%, 22%);--error-lighter: hsl(0, 100%, 96.8%);--error-light: hsl(0, 90.2%, 91.9%);--error-main: hsl(358, 75%, 59%);--error-main-8-p: hsla(358, 75%, 59%, .08);--error-main-50-p: hsla(358, 75%, 59%, .5);--error-dark: hsl(358, 67.4%, 54.6%);--error-darker: hsl(358, 65%, 47%);--error-outlined-border: hsl(358, 75%, 59%);--error-contrast-text: hsl(350, 63%, 24%);--error-button-contrast-text: hsl(0, 0%, 100%);--aba: #FFC134;--abb: #4F4FF5}[_nghost-%COMP%]{margin:0;padding:0;display:flex;align-items:center;box-sizing:border-box}.fu-tabs-page[_nghost-%COMP%]{gap:16px;border-bottom:1px solid var(--common-divider, hsl(0, 0%, 86.8%));box-sizing:border-box}"], changeDetection: 0 }); }
}
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(TabsV4Component, [{
        type: Component,
        args: [{ selector: 'fusion-tabs', standalone: true, imports: [CommonModule], host: { class: 'fusion-v4' }, template: '<ng-content></ng-content>', changeDetection: ChangeDetectionStrategy.OnPush, styles: [".fusion-v4{--background-default: #FFFFFF;--background-paper: hsl(0, 0%, 99%);--background-model-elevation: #FFFFFF;--background-backdrop: hsla(0, 0%, 0%, .11);--background-paper-elevation-0: hsl(0, 0%, 97.5%);--background-paper-elevation-1: hsl(0, 0%, 94.6%);--background-paper-elevation-2: hsl(0, 0%, 92%);--background-paper-elevation-3: hsl(0, 0%, 89.5%);--background-paper-elevation-4: hsl(0, 0%, 86.8%);--background-paper-elevation-5: hsl(0, 0%, 83%);--background-paper-elevation-6: hsl(0, 0%, 73.2%);--background-paper-elevation-7: hsl(0, 0%, 55.2%);--background-paper-elevation-8: hsl(0, 0%, 50.3%);--background-paper-elevation-9: hsl(0, 0%, 39.3%);--action-primary: hsl(0, 0%, 12.5%);--action-active: hsl(0, 0%, 50.3%);--action-hover: hsla(0, 0%, 0%, .05);--action-selected: hsl(0, 0%, 92%);--action-disabled: hsl(0, 0%, 87%);--action-disabled-background: hsl(0, 0%, 95%);--action-focus: hsl(0, 0%, 92%);--action-outlined-border: hsl(0, 0%, 73%);--default-light: hsl(0, 0%, 89.5%);--default-main: hsl(0, 0%, 94.51%);--default-dark: hsl(0, 0%, 92%);--default-outlined-border: hsl(0, 0%, 73.2%);--default-contrast-text: hsl(0, 0%, 12.5%);--default-button-contrast-text: hsl(0, 0%, 0%);--common-white: #FFFFFF;--common-black: #000000;--common-inverse-white: #FFFFFF;--common-inverse-black: #000000;--common-divider: hsl(0, 0%, 86.8%);--common-divider-elevation-0: hsl(0, 0%, 89%);--text-primary: hsl(0, 0%, 12.5%);--text-secondary: hsl(0, 0%, 39.3%);--text-disabled: hsl(0, 0%, 73.33%);--primary-lighter: hsl(209, 100%, 96.5%);--primary-light: hsl(209, 95%, 90.1%);--primary-main: hsl(206, 100%, 50%);--primary-main-8-p: hsla(206, 100%, 50%, .08);--primary-main-50-p: hsla(206, 100%, 50%, .5);--primary-dark: hsl(208, 93.5%, 47.4%);--primary-darker: hsl(211, 90%, 42%);--primary-outlined-border: hsl(206, 100%, 50%);--primary-contrast-text: hsl(216, 71%, 23%);--primary-button-contrast-text: hsl(0, 0%, 100%);--info-lighter: hsl(223, 98.4%, 97.1%);--info-light: hsl(224, 87.1%, 92%);--info-main: hsl(226, 70%, 55.5%);--info-main-8-p: hsla(226, 70%, 55.5%, .08);--info-main-50-p: hsla(226, 70%, 55.5%, .5);--info-dark: hsl(226, 58.6%, 51.3%);--info-darker: hsl(226, 55%, 45%);--info-outlined-border: hsl(226, 70%, 55.5%);--info-contrast-text: hsl(226, 50%, 24%);--info-button-contrast-text: hsl(0, 0%, 100%);--success-lighter: hsl(139, 55.2%, 94.5%);--success-light: hsl(141, 43.7%, 86%);--success-main: hsl(151, 55%, 41.5%);--success-main-8-p: hsla(151, 55%, 41.5%, .08);--success-main-50-p: hsla(151, 55%, 41.5%, .5);--success-dark: hsl(152, 57.5%, 37.6%);--success-darker: hsl(153, 67%, 28.5%);--success-outlined-border: hsl(151, 55%, 41.5%);--success-contrast-text: hsl(155, 40%, 16.5%);--success-button-contrast-text: hsl(0, 0%, 100%);--warning-lighter: hsl(45, 100%, 90.8%);--warning-light: hsl(40, 100%, 81.5%);--warning-main: hsl(42, 100%, 62%);--warning-main-8-p: hsla(42, 100%, 62%, .08);--warning-main-50-p: hsla(42, 100%, 62%, .5);--warning-dark: hsl(42, 100%, 55%);--warning-darker: hsl(25, 50%, 38%);--warning-outlined-border: hsl(42, 100%, 62%);--warning-contrast-text: hsl(25, 40%, 22%);--warning-button-contrast-text: hsl(24, 40%, 22%);--error-lighter: hsl(0, 100%, 96.8%);--error-light: hsl(0, 90.2%, 91.9%);--error-main: hsl(358, 75%, 59%);--error-main-8-p: hsla(358, 75%, 59%, .08);--error-main-50-p: hsla(358, 75%, 59%, .5);--error-dark: hsl(358, 67.4%, 54.6%);--error-darker: hsl(358, 65%, 47%);--error-outlined-border: hsl(358, 75%, 59%);--error-contrast-text: hsl(350, 63%, 24%);--error-button-contrast-text: hsl(0, 0%, 100%);--aba: #FFC134;--abb: #4F4FF5}:host{margin:0;padding:0;display:flex;align-items:center;box-sizing:border-box}:host.fu-tabs-page{gap:16px;border-bottom:1px solid var(--common-divider, hsl(0, 0%, 86.8%));box-sizing:border-box}\n"] }]
    }], () => [{ type: i0.ElementRef }, { type: i0.Renderer2 }], { variant: [{
            type: Input
        }], isPage: [{
            type: HostBinding,
            args: ['class.fu-tabs-page']
        }], selectedChange: [{
            type: Output
        }], tabList: [{
            type: ContentChildren,
            args: [TabV4Component]
        }], testId: [{
            type: Input
        }] }); })();
(() => { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassDebugInfo(TabsV4Component, { className: "TabsV4Component", filePath: "tabs/tabs-v4.component.ts", lineNumber: 30 }); })();

/**
 * Generated bundle index. Do not edit.
 */

export { TabV4Component as TabComponent, TabsV4Component as TabsComponent };
//# sourceMappingURL=ironsource-fusion-ui-components-tabs-v4.mjs.map
